/// <reference types="react" />
import '../../yamui';
import * as React from 'react';
import { BaseComponentProps } from '../../util/BaseComponent/props';
import { BaseIcon } from '../Icon';
import './ActionLink.css';
export interface BaseActionLinkProps extends BaseComponentProps {
    /**
     * The icon component class to be rendered.
     */
    icon: typeof BaseIcon;
    /**
     * A well-curated string describing the action for screen readers.
     */
    ariaLabel?: string;
    /**
     * The visible text.
     */
    text: string;
}
export interface NavigationActionLinkProps extends BaseActionLinkProps {
    /**
     * A valid URL.
     */
    href: string;
    /**
     * Whether the link should open in a new window. It securely removes access to the opening window.
     */
    newWindow?: boolean;
}
export interface ClickableActionLinkProps extends BaseActionLinkProps {
    /**
     * A click handler.
     */
    onClick: ((e: React.MouseEvent<HTMLButtonElement | HTMLLinkElement>) => void);
}
export declare type ActionLinkProps = NavigationActionLinkProps | ClickableActionLinkProps;
/**
 * An actionable element with icon and text which will either render a button with an onClick callback
 * or a navigation link.
 */
export default class ActionLink extends React.Component<ActionLinkProps> {
    render(): JSX.Element;
}
