"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var index_1 = require("./index");
var Down_1 = require("../Icon/icons/Down");
describe('<ActionLink />', function () {
    var component;
    describe('with href', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { text: "Download", icon: Down_1.default, href: "https://yammer.com", newWindow: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with href and ariaLabel', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { text: "Download", icon: Down_1.default, ariaLabel: "Download file", href: "https://yammer.com", newWindow: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with onClick', function () {
        var onClick;
        beforeEach(function () {
            onClick = jest.fn();
            component = enzyme_1.shallow(React.createElement(index_1.default, { text: "Download", icon: Down_1.default, onClick: onClick }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('when clicked', function () {
            beforeEach(function () {
                component.simulate('click');
            });
            it('calls props.onClick', function () {
                expect(onClick).toHaveBeenCalledTimes(1);
            });
        });
    });
    describe('with onClick and ariaLabel', function () {
        var onClick;
        beforeEach(function () {
            onClick = jest.fn();
            component = enzyme_1.shallow(React.createElement(index_1.default, { text: "Download", ariaLabel: "Download file", icon: Down_1.default, onClick: onClick }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { className: "TEST_CLASSNAME", text: "Download", icon: Down_1.default, ariaLabel: "Download the file", href: "https://yammer.com" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=ActionLink.test.js.map