"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var react_test_renderer_1 = require("react-test-renderer");
var test_utils_1 = require("react-dom/test-utils");
var _1 = require(".");
var Clickable_1 = require("../Clickable");
var render = function (jsx) {
    return react_test_renderer_1.create(jsx).toJSON();
};
describe('<Block />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, null, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { className: "TEST_CLASSNAME" }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with xLarge text size', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { textSize: _1.TextSize.XLARGE }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with secondary textColor', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { textColor: _1.TextColor.SECONDARY }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with textAlign', function () {
        describe('right', function () {
            beforeEach(function () {
                component = render(React.createElement(_1.default, { textAlign: "right" }, "block content"));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('center', function () {
            beforeEach(function () {
                component = render(React.createElement(_1.default, { textAlign: "center" }, "block content"));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with ellipsis', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { ellipsis: true }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with top spacing', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { topSpacing: _1.GutterSize.SMALL }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with bottom spacing', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { bottomSpacing: _1.GutterSize.XLARGE }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with padding', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { padding: _1.GutterSize.SMALL }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with horizontal padding', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { horizontalPadding: _1.GutterSize.MEDIUM }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with vertical padding', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { verticalPadding: _1.GutterSize.XLARGE }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with positive push', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { push: 3 }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with negative push', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { push: -2 }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('within clickable', function () {
        var rendered;
        beforeEach(function () {
            rendered = test_utils_1.renderIntoDocument(React.createElement(Clickable_1.default, null,
                React.createElement(_1.default, null, "block content")));
        });
        it('matches its snapshot', function () {
            expect(test_utils_1.findRenderedDOMComponentWithClass(rendered, 'y-block')).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=Block.test.js.map