"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
require("../../yamui");
var React = require("react");
var BaseButton_1 = require("office-ui-fabric-react/lib/components/Button/BaseButton");
var Block_1 = require("../Block");
var Spinner_1 = require("../Spinner");
var types_1 = require("./types");
exports.ButtonColor = types_1.ButtonColor;
exports.ButtonStatus = types_1.ButtonStatus;
exports.ButtonIconPosition = types_1.ButtonIconPosition;
exports.ButtonSize = types_1.ButtonSize;
exports.ButtonType = types_1.ButtonType;
var Button_styles_1 = require("./Button.styles");
require("./Button.css");
var hrefBlacklist = ['', '#', 'javascript://'];
/**
 * A `Button` allows a user to take an action.
 */
var Button = /** @class */ (function (_super) {
    __extends(Button, _super);
    function Button() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Button.prototype.render = function () {
        var _a = this.props, ariaLabel = _a.ariaLabel, type = _a.type, onClick = _a.onClick, onFocus = _a.onFocus, onBlur = _a.onBlur, onMouseEnter = _a.onMouseEnter, onMouseLeave = _a.onMouseLeave, className = _a.className;
        var href = this.props.href;
        var newWindow = this.props.newWindow;
        var target = newWindow ? '_blank' : undefined;
        var status = this.props.status;
        var isDisabled = status === types_1.ButtonStatus.DISABLED || status === types_1.ButtonStatus.LOADING;
        return (React.createElement(BaseButton_1.BaseButton, { ariaLabel: ariaLabel, className: "y-button " + (className ? className : ''), disabled: isDisabled, href: href, target: target, type: href ? '' : type, onBlur: onBlur, onClick: onClick, onFocus: onFocus, onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave, styles: Button_styles_1.getStyles(this.props) },
            this.getContents(),
            this.isLoading() && this.getSpinner()));
    };
    Button.prototype.getContents = function () {
        var _a = this.props, Icon = _a.icon, iconPosition = _a.iconPosition, size = _a.size, text = _a.text, secondaryText = _a.secondaryText;
        var textSize = size === types_1.ButtonSize.SMALL ? Block_1.TextSize.SMALL : Block_1.TextSize.MEDIUM_SUB;
        var buttonIcon = Icon && (React.createElement("span", { className: "y-button--icon-wrapper-" + iconPosition },
            React.createElement(Icon, null)));
        var className = this.isLoading() ? 'y-button--content__hidden' : '';
        var leftIcon = iconPosition === 'left' && buttonIcon;
        var rightIcon = iconPosition === 'right' && buttonIcon;
        return (React.createElement(Block_1.default, { textSize: textSize, className: className, textAlign: "center" },
            leftIcon,
            text,
            rightIcon,
            React.createElement("div", { className: "y-button--secondary-text" },
                leftIcon,
                secondaryText,
                rightIcon)));
    };
    Button.prototype.getSpinner = function () {
        var _a = this.props, color = _a.color, size = _a.size;
        var loadingText = this.props.loadingText;
        var spinnerColor = color === types_1.ButtonColor.PRIMARY ? Spinner_1.SpinnerColor.DARK : Spinner_1.SpinnerColor.LIGHT;
        var spinnerSize = size === types_1.ButtonSize.SMALL ? Spinner_1.SpinnerSize.XSMALL : Spinner_1.SpinnerSize.SMALL;
        return (React.createElement("span", { className: "y-button--spinner" },
            React.createElement(Spinner_1.default, { color: spinnerColor, size: spinnerSize, text: loadingText, hideText: true, isCentered: true })));
    };
    Button.prototype.isLoading = function () {
        return this.props.status === types_1.ButtonStatus.LOADING;
    };
    Button.propTypes = {
        // TypeScript does not support negated types, so we need to do a runtime validation instead.
        href: function (props, propName, componentName) {
            var href = props.href;
            if (typeof href !== 'string') {
                return;
            }
            if (hrefBlacklist.indexOf(href) > -1) {
                return new Error("Invalid prop " + propName + " supplied to " + componentName + ": \"" + href + "\".\n          Please use a Button for actions, NavigationLink (or Button with href) for navigation.");
            }
        },
    };
    Button.defaultProps = {
        color: types_1.ButtonColor.SECONDARY,
        iconPosition: types_1.ButtonIconPosition.LEFT,
        size: types_1.ButtonSize.REGULAR,
        status: types_1.ButtonStatus.ENABLED,
        type: types_1.ButtonType.BUTTON,
    };
    return Button;
}(React.Component));
exports.default = Button;
//# sourceMappingURL=Button.js.map