"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var _1 = require(".");
var Accounts_1 = require("../Icon/icons/Accounts");
var sampleText = 'Click Me';
var sampleAriaLabel = 'Aria description';
describe('<Button />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with button type', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, type: _1.ButtonType.BUTTON }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with submit type', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, type: _1.ButtonType.SUBMIT }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with reset type', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, type: _1.ButtonType.RESET }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with aria label', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, ariaLabel: sampleAriaLabel }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with fullWidth', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, fullWidth: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('set as disabled', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, status: _1.ButtonStatus.DISABLED }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('set as loading', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, status: _1.ButtonStatus.LOADING }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with icon', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { icon: Accounts_1.default, text: sampleText }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('on the right', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { icon: Accounts_1.default, text: sampleText, iconPosition: _1.ButtonIconPosition.RIGHT }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with primary color', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { color: _1.ButtonColor.PRIMARY, text: sampleText }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('set as loading', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { color: _1.ButtonColor.PRIMARY, text: sampleText, status: _1.ButtonStatus.LOADING }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with small size', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.ButtonSize.SMALL, text: sampleText }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('with icon', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { icon: Accounts_1.default, size: _1.ButtonSize.SMALL, text: sampleText }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('set as loading', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.ButtonSize.SMALL, text: sampleText, status: _1.ButtonStatus.LOADING }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with valid href', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, href: "https://www.yammer.com" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('with newWindow', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, href: "https://www.yammer.com", newWindow: true }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with invalid href', function () {
        beforeEach(function () {
            jest.spyOn(console, 'error').mockImplementation(function () { });
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, href: "#" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        it('raises a propTypes validation error', function () {
            var err = 'Please use a Button for actions, NavigationLink (or Button with href) for navigation';
            expect(console.error).toHaveBeenCalledWith(expect.stringContaining(err));
        });
    });
    describe('with event callbacks', function () {
        var onClick;
        var onMouseEnter;
        var onMouseLeave;
        var onFocus;
        var onBlur;
        beforeEach(function () {
            onClick = jest.fn();
            onMouseEnter = jest.fn();
            onMouseLeave = jest.fn();
            onFocus = jest.fn();
            onBlur = jest.fn();
            component = enzyme_1.shallow(React.createElement(_1.default, { text: sampleText, onClick: onClick, onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave, onFocus: onFocus, onBlur: onBlur }));
        });
        describe('when clicked', function () {
            beforeEach(function () {
                component.simulate('click');
            });
            it('triggers its onClick callback', function () {
                expect(onClick).toHaveBeenCalled();
            });
        });
        describe('when hovered', function () {
            beforeEach(function () {
                component.simulate('mouseEnter');
            });
            it('triggers its onMouseEnter callback', function () {
                expect(onMouseEnter).toHaveBeenCalled();
            });
        });
        describe('when hovered out', function () {
            beforeEach(function () {
                component.simulate('mouseLeave');
            });
            it('triggers its onMouseLeave callback', function () {
                expect(onMouseLeave).toHaveBeenCalled();
            });
        });
        describe('when focused', function () {
            beforeEach(function () {
                component.simulate('focus');
            });
            it('triggers its onFocus callback', function () {
                expect(onFocus).toHaveBeenCalled();
            });
        });
        describe('when blurred', function () {
            beforeEach(function () {
                component.simulate('blur');
            });
            it('triggers its onBlur callback', function () {
                expect(onBlur).toHaveBeenCalled();
            });
        });
    });
});
//# sourceMappingURL=Button.test.js.map