/// <reference types="react" />
import '../../yamui';
import * as React from 'react';
import { NestableBaseComponentProps, FocusableComponentProps } from '../../util/BaseComponent/props';
import './Clickable.css';
export interface ClickableProps extends NestableBaseComponentProps, FocusableComponentProps {
    /**
     * Additional label that must be provided if the clickable text is not descriptive enough.
     */
    ariaLabel?: string;
    /**
     * Whether the clickable should be `display: block`.
     */
    block?: boolean;
    /**
     * Title or description of the linked document.
     */
    title?: string;
    /**
     * Whether to remove all styles from the link. Useful for allowing a large area to be clickable
     * while nesting `FakeLink` components to show link and hover state visuals.
     */
    unstyled?: boolean;
    /**
     * Click callback handler.
     */
    onClick?: ((event: React.MouseEvent<HTMLButtonElement>) => void);
}
export interface ClickableContext {
    withinClickable: boolean;
}
export declare const ClickableContext: React.Context<ClickableContext>;
/**
 * A `Clickable` is an accessible, clickable area that accepts arbitrary children. It is styled
 * like a link by default, but can also be unstyled. Under the hood `Clickable` simply wraps
 * content in a `button` element.
 */
export default class Clickable extends React.Component<ClickableProps> {
    private buttonRef;
    constructor(props: ClickableProps);
    render(): JSX.Element;
    focus(): void;
    private getClasses();
}
