"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var _1 = require(".");
var react_test_renderer_1 = require("react-test-renderer");
var test_utils_1 = require("react-dom/test-utils");
var render = function (jsx) {
    return react_test_renderer_1.create(jsx).toJSON();
};
describe('<Clickable />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, null, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { className: "TEST_CLASSNAME" }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when unstyled', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { unstyled: true }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when block is true', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { block: true }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when title is passed', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { title: "extra browser tooltip content" }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when ariaLabel is passed', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { ariaLabel: "aria label content" }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when focusableRef is passed', function () {
        var button;
        var focusable;
        beforeEach(function () {
            var setFocusable = function (f) {
                focusable = f;
            };
            var rendered = test_utils_1.renderIntoDocument(React.createElement(_1.default, { focusableRef: setFocusable }, "clickable content"));
            button = test_utils_1.findRenderedDOMComponentWithClass(rendered, 'y-clickable');
        });
        it('matches its snapshot', function () {
            expect(button).toMatchSnapshot();
        });
        describe('when focusable is used', function () {
            beforeEach(function () {
                jest.spyOn(button, 'focus');
                focusable.focus();
            });
            it('calls focus on underlying button', function () {
                expect(button.focus).toHaveBeenCalledTimes(1);
            });
        });
    });
    describe('when clicked', function () {
        var clicked;
        var renderedDOM;
        function clickMe() {
            clicked = true;
        }
        beforeEach(function () {
            clicked = false;
            var renderedInstance = test_utils_1.renderIntoDocument(React.createElement(_1.default, { onClick: clickMe }, "clickable content"));
            renderedDOM = test_utils_1.findRenderedDOMComponentWithClass(renderedInstance, 'y-clickable');
        });
        it('triggers its onClick callback', function () {
            test_utils_1.Simulate.click(renderedDOM);
            expect(clicked).toBe(true);
        });
    });
});
//# sourceMappingURL=Clickable.test.js.map