"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
require("../../yamui");
var React = require("react");
var Dropdown_1 = require("office-ui-fabric-react/lib/Dropdown");
exports.DropdownMenuItemType = Dropdown_1.DropdownMenuItemType;
var classNames_1 = require("../../util/classNames");
var Icon_1 = require("../Icon");
var ChevronDownMed_1 = require("../Icon/icons/ChevronDownMed");
var Block_1 = require("../Block");
var Text_1 = require("../Text");
var FixedGrid_1 = require("../FixedGrid");
require("./Dropdown.css");
/**
 * A `Dropdown` is a list in which the selected item is always visible, and the others are visible
 * on demand by clicking a button.
 */
var Dropdown = /** @class */ (function (_super) {
    __extends(Dropdown, _super);
    function Dropdown() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.getChevronIcon = function () {
            return React.createElement(ChevronDownMed_1.default, { className: "y-dropdown__caretDown", size: Icon_1.IconSize.MEDIUM });
        };
        _this.getPlaceholder = function () {
            return React.createElement(Block_1.default, { textSize: Text_1.TextSize.MEDIUM_SUB }, _this.props.placeHolder);
        };
        _this.getOption = function (item) {
            if (!item) {
                return null;
            }
            var isHeader = item.itemType === Dropdown_1.DropdownMenuItemType.Header;
            if (isHeader) {
                return (React.createElement(Block_1.default, { className: "y-dropdown--item y-dropdown--header", textSize: Text_1.TextSize.SMALL }, item.text));
            }
            return (React.createElement(Block_1.default, { className: "y-dropdown--item", textSize: Text_1.TextSize.MEDIUM_SUB }, _this.getOptionContent(item)));
        };
        // Fabric Dropdown can support multiple selection. Even though we're not supporting it, TypeScript
        // requires we handle these cases. So some branches cannot actually be reached/tested. RIP 100% coverage :(
        _this.getSelectedOption = function (item) {
            if (Array.isArray(item)) {
                return item.length > 0 ? _this.getOption(item[0]) : _this.getOption();
            }
            return _this.getOption(item);
        };
        _this.handleChanged = function (option) {
            var onChanged = _this.props.onChanged;
            if (onChanged) {
                onChanged(option.key);
            }
        };
        return _this;
    }
    Dropdown.prototype.render = function () {
        var _a = this.props, ariaLabel = _a.ariaLabel, className = _a.className, label = _a.label, placeHolder = _a.placeHolder, selectedKey = _a.selectedKey;
        var calloutProps = {
            directionalHintFixed: false,
            doNotLayer: true,
            preventDismissOnScroll: true,
        };
        return (React.createElement("div", { className: classNames_1.join(['y-dropdown', className]) },
            React.createElement(Dropdown_1.Dropdown, { ariaLabel: ariaLabel, label: label, options: this.getFabricOptions(), placeHolder: placeHolder, selectedKey: selectedKey, onChanged: this.handleChanged, onRenderCaretDown: this.getChevronIcon, onRenderOption: this.getOption, onRenderTitle: this.getSelectedOption, onRenderPlaceHolder: this.getPlaceholder, calloutProps: calloutProps })));
    };
    Dropdown.prototype.getOptionText = function (label, text) {
        if (label) {
            return (React.createElement("span", null,
                React.createElement(Text_1.default, { bold: true },
                    label,
                    ":"),
                " ",
                text));
        }
        return React.createElement("span", null, text);
    };
    Dropdown.prototype.getOptionContent = function (item) {
        var label = item.data && item.data.label;
        var Icon = item.data && item.data.icon;
        var iconNode = Icon && React.createElement(Icon, { size: Icon_1.IconSize.MEDIUM, block: true });
        var textContent = this.getOptionText(label, item.text);
        if (iconNode) {
            return (React.createElement(FixedGrid_1.FixedGridRow, { gutterSize: FixedGrid_1.GutterSize.SMALL },
                React.createElement(FixedGrid_1.FixedGridColumn, { fixed: true, className: "y-dropdown--option-icon" }, iconNode),
                React.createElement(FixedGrid_1.FixedGridColumn, { className: "y-dropdown--ellipsed-title" }, textContent)));
        }
        return React.createElement("div", { className: "y-dropdown--ellipsed-title" }, textContent);
    };
    Dropdown.prototype.getFabricOptions = function () {
        return this.props.options.map(function (item) {
            return {
                key: item.key,
                text: item.text,
                itemType: item.itemType,
                data: {
                    icon: item.icon,
                    label: item.label,
                },
            };
        });
    };
    return Dropdown;
}(React.Component));
exports.default = Dropdown;
//# sourceMappingURL=Dropdown.js.map