"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var Dropdown_1 = require("office-ui-fabric-react/lib/components/Dropdown");
var _1 = require(".");
var Add_1 = require("../Icon/icons/Add");
describe('<Dropdown />', function () {
    var component;
    var fullComponent;
    describe('with default options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { options: [] }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { options: [], className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with all props', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { ariaLabel: "ARIA_LABEL", options: [{ key: 'A', text: 'Option a' }, { key: 'B', text: 'Option b' }], className: "TEST_CLASSNAME", selectedKey: "A", placeHolder: "TEST_PLACEHOLDER", label: "TEST_LABEL", onChanged: jest.fn() }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('option templates', function () {
        describe('with icon', function () {
            beforeEach(function () {
                var options = [{ key: 'A', text: 'with icon', icon: Add_1.default }];
                fullComponent = enzyme_1.mount(React.createElement(_1.default, { options: options }));
                fullComponent.find('.ms-Dropdown').simulate('click');
            });
            it('matches its snapshot', function () {
                expect(fullComponent.find('.ms-Dropdown-items .y-dropdown--item').hostNodes()).toMatchSnapshot();
            });
        });
        describe('with label', function () {
            beforeEach(function () {
                var options = [{ key: 'A', text: 'with icon', label: 'label' }];
                fullComponent = enzyme_1.mount(React.createElement(_1.default, { options: options }));
                fullComponent.find('.ms-Dropdown').simulate('click');
            });
            it('matches its snapshot', function () {
                expect(fullComponent.find('.ms-Dropdown-items .y-dropdown--item').hostNodes()).toMatchSnapshot();
            });
        });
    });
    describe('with divider', function () {
        beforeEach(function () {
            var options = [{ key: 'divider', text: 'divider1', itemType: _1.DropdownMenuItemType.Divider }];
            fullComponent = enzyme_1.mount(React.createElement(_1.default, { options: options }));
            fullComponent.find('.ms-Dropdown').simulate('click');
        });
        it('matches its snapshot', function () {
            expect(fullComponent.find('.ms-Dropdown-items .y-dropdown--item')).toMatchSnapshot();
        });
    });
    describe('with section header', function () {
        beforeEach(function () {
            var options = [{ key: 'header', text: 'header1', itemType: _1.DropdownMenuItemType.Header }];
            fullComponent = enzyme_1.mount(React.createElement(_1.default, { options: options }));
            fullComponent.find('.ms-Dropdown').simulate('click');
        });
        it('matches its snapshot', function () {
            expect(fullComponent.find('.ms-Dropdown-items .y-dropdown--item').hostNodes()).toMatchSnapshot();
        });
    });
    describe('when fully rendered', function () {
        beforeEach(function () {
            fullComponent = enzyme_1.mount(React.createElement(_1.default, { options: [] }));
        });
        it('displays our custom caret icon', function () {
            expect(fullComponent.find('.y-dropdown__caretDown').hostNodes().length).toBe(1);
        });
    });
    describe('with onChanged handler', function () {
        var callback;
        var options = [{ key: 'A', text: 'Option a' }, { key: 'B', text: 'Option b' }];
        beforeEach(function () {
            callback = jest.fn();
            component = enzyme_1.shallow(React.createElement(_1.default, { options: options, onChanged: callback }));
        });
        describe('when an option is selected', function () {
            var fabricDropdown;
            beforeEach(function () {
                fabricDropdown = component.find(Dropdown_1.Dropdown);
                fabricDropdown.simulate('changed', options[1]);
            });
            it('triggers the onChanged callback with key', function () {
                expect(callback).toHaveBeenCalledWith(options[1].key);
            });
        });
    });
    describe('without onChanged handler', function () {
        var options = [{ key: 'A', text: 'Option a' }, { key: 'B', text: 'Option b' }];
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { options: options }));
        });
        describe('when an option is selected', function () {
            var fabricDropdown;
            beforeEach(function () {
                fabricDropdown = component.find(Dropdown_1.Dropdown);
                fabricDropdown.simulate('changed', options[1]);
            });
            it('does not blow up', function () {
                expect(component.update()).toMatchSnapshot();
            });
        });
    });
    describe('when onRenderTitle is called with null', function () {
        var result;
        beforeEach(function () {
            var fabricDropdown = component.find(Dropdown_1.Dropdown);
            var onRenderTitle = fabricDropdown.prop('onRenderTitle');
            if (onRenderTitle) {
                result = onRenderTitle(undefined);
            }
        });
        it('returns the expected value', function () {
            expect(result).toMatchSnapshot();
        });
    });
    describe('when onRenderTitle is called with an empty array', function () {
        var result;
        beforeEach(function () {
            var fabricDropdown = component.find(Dropdown_1.Dropdown);
            var onRenderTitle = fabricDropdown.prop('onRenderTitle');
            if (onRenderTitle) {
                result = onRenderTitle([]);
            }
        });
        it('renders as expected', function () {
            expect(result).toMatchSnapshot();
        });
    });
    describe('when onRenderTitle is called with an array of items', function () {
        var result;
        beforeEach(function () {
            var fabricDropdown = component.find(Dropdown_1.Dropdown);
            var onRenderTitle = fabricDropdown.prop('onRenderTitle');
            if (onRenderTitle) {
                result = onRenderTitle([
                    { itemType: _1.DropdownMenuItemType.Header, key: '1', text: 'foo' },
                    { key: '2', text: 'bar' },
                ]);
            }
        });
        it('renders as expected', function () {
            expect(result).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=Dropdown.test.js.map