"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
require("../../yamui");
var React = require("react");
var classNames_1 = require("../../util/classNames");
var Clickable_1 = require("../Clickable");
var Edit_1 = require("../Icon/icons/Edit");
var TextField_1 = require("../TextField");
require("./EditableText.css");
/**
 * Displays text which can be edited on click.
 */
var EditableText = /** @class */ (function (_super) {
    __extends(EditableText, _super);
    function EditableText(props) {
        var _this = _super.call(this, props) || this;
        _this.onKeyDown = function (event) {
            switch (event.which) {
                case 27 /* escape */:
                    event.preventDefault();
                    _this.cancelEdit();
                    break;
                case 13 /* enter */:
                    event.preventDefault();
                    _this.commitEdit();
                    break;
                default:
            }
        };
        _this.setTextFieldFocusable = function (focusable) {
            _this.textFieldFocusable = focusable;
        };
        _this.setClickableFocusable = function (focusable) {
            _this.clickableFocusable = focusable;
        };
        _this.updateInternalEditedDescription = function (description) {
            _this.setState(function () { return ({ editedValue: description }); });
        };
        _this.handleEditClick = function (event) {
            event.stopPropagation();
            _this.setState(function () { return ({ isEditing: true, editedValue: _this.props.text || '' }); });
            if (_this.props.onBeginEditing) {
                _this.props.onBeginEditing();
            }
        };
        _this.cancelEdit = function () {
            _this.setState(function () { return ({ isEditing: false, editedValue: '' }); });
            if (_this.props.onEndEditing) {
                _this.props.onEndEditing();
            }
        };
        _this.commitEdit = function () {
            var editedValue = _this.state.editedValue;
            _this.setState(function () { return ({ isEditing: false, editedValue: '' }); });
            if (_this.props.onUpdate) {
                _this.props.onUpdate(editedValue);
            }
            if (_this.props.onEndEditing) {
                _this.props.onEndEditing();
            }
        };
        _this.textFieldFocusable = null;
        _this.clickableFocusable = null;
        _this.state = { isEditing: false, editedValue: '' };
        return _this;
    }
    EditableText.prototype.render = function () {
        var _a = this.state, editedValue = _a.editedValue, isEditing = _a.isEditing;
        var _b = this.props, text = _b.text, promptText = _b.promptText, placeHolder = _b.placeHolder, maxLength = _b.maxLength, className = _b.className;
        var classes = classNames_1.join(['y-editableText', className]);
        if (isEditing) {
            return (React.createElement("div", { className: classes },
                React.createElement(TextField_1.default, { className: "y-editableText--textfield", underlined: true, onChange: this.updateInternalEditedDescription, value: editedValue, placeHolder: placeHolder, maxLength: maxLength, focusableRef: this.setTextFieldFocusable, onBlur: this.commitEdit, onKeyDown: this.onKeyDown })));
        }
        return (React.createElement("span", { className: classes },
            React.createElement(Clickable_1.default, { onClick: this.handleEditClick, unstyled: true, className: "y-editableText--clickable", ariaLabel: promptText, focusableRef: this.setClickableFocusable },
                React.createElement(Edit_1.default, null),
                React.createElement("span", { className: "y-editableText--clickableText" }, text || promptText))));
    };
    EditableText.prototype.componentDidUpdate = function (_prevProps, prevState) {
        // Set focus when we enter edit mode
        if (this.state.isEditing && !prevState.isEditing) {
            this.setTextFieldFocus();
        }
        // Restore focus after leaving edit mode
        if (!this.state.isEditing && prevState.isEditing) {
            this.setClickableFocus();
        }
    };
    EditableText.prototype.setTextFieldFocus = function () {
        if (this.textFieldFocusable) {
            this.textFieldFocusable.focus();
        }
    };
    EditableText.prototype.setClickableFocus = function () {
        if (this.clickableFocusable) {
            this.clickableFocusable.focus();
        }
    };
    return EditableText;
}(React.Component));
exports.default = EditableText;
//# sourceMappingURL=EditableText.js.map