"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
require("../../yamui");
var React = require("react");
var FixedGrid_1 = require("../FixedGrid");
var types_1 = require("./types");
exports.MediaObjectSize = types_1.MediaObjectSize;
var MediaObjectTitle_1 = require("./MediaObjectTitle");
var MediaObjectMetadata_1 = require("./MediaObjectMetadata");
var MediaObjectExtra_1 = require("./MediaObjectExtra");
require("./MediaObject.css");
var ImageWidthMap = (_a = {},
    _a[types_1.MediaObjectSize.XLARGE] = 72,
    _a[types_1.MediaObjectSize.LARGE] = 48,
    _a[types_1.MediaObjectSize.MEDIUM] = 40,
    _a[types_1.MediaObjectSize.SMALL] = 32,
    _a[types_1.MediaObjectSize.XSMALL] = 24,
    _a);
/**
 * A `MediaObject` renders an image on the left with blocks of descriptive content on the right. The
 * image area, and pieces of text content, are passed in as props, with size and layout determined
 * by the `size` prop.
 */
var MediaObject = /** @class */ (function (_super) {
    __extends(MediaObject, _super);
    function MediaObject() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MediaObject.prototype.render = function () {
        var _a = this.props, size = _a.size, imageContent = _a.imageContent, titleContent = _a.titleContent, metadataContent = _a.metadataContent, extraContent = _a.extraContent, children = _a.children, allowTextWrap = _a.allowTextWrap;
        var gutterSize = this.getGutterSize();
        var imageColumnClass = "y-media-object__size-" + size + "--image";
        var titleContentChild = titleContent && (React.createElement(MediaObjectTitle_1.default, { ellipsis: !allowTextWrap, size: size }, titleContent));
        var metadataContentChild = this.showMetadata() && (React.createElement(MediaObjectMetadata_1.default, { ellipsis: !allowTextWrap, size: size }, metadataContent));
        var extraContentChild = this.showExtra() && (React.createElement(MediaObjectExtra_1.default, { ellipsis: !allowTextWrap }, extraContent));
        return (React.createElement("div", { className: this.getClasses() },
            React.createElement(FixedGrid_1.FixedGridRow, { gutterSize: gutterSize },
                React.createElement(FixedGrid_1.FixedGridColumn, { width: ImageWidthMap[size], fixed: true, className: imageColumnClass }, imageContent),
                React.createElement(FixedGrid_1.FixedGridColumn, null,
                    titleContentChild,
                    metadataContentChild,
                    extraContentChild,
                    children))));
    };
    MediaObject.prototype.getClasses = function () {
        var _a = this.props, className = _a.className, size = _a.size;
        var classes = ['y-media-object', "y-media-object__size-" + size];
        if (className) {
            classes.push(className);
        }
        return classes.join(' ');
    };
    MediaObject.prototype.getGutterSize = function () {
        var size = this.props.size;
        return size === types_1.MediaObjectSize.XLARGE ? FixedGrid_1.GutterSize.XLARGE : FixedGrid_1.GutterSize.MEDIUM;
    };
    MediaObject.prototype.showMetadata = function () {
        var _a = this.props, metadataContent = _a.metadataContent, size = _a.size;
        if (!metadataContent) {
            return false;
        }
        if (size === types_1.MediaObjectSize.XSMALL) {
            return false;
        }
        return true;
    };
    MediaObject.prototype.showExtra = function () {
        var _a = this.props, extraContent = _a.extraContent, size = _a.size;
        if (!extraContent) {
            return false;
        }
        return size === types_1.MediaObjectSize.XLARGE;
    };
    return MediaObject;
}(React.Component));
exports.default = MediaObject;
var _a;
//# sourceMappingURL=MediaObject.js.map