"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var _1 = require(".");
describe('<MediaObject />', function () {
    var component;
    var image;
    var title;
    var metadata;
    var extra;
    var children;
    beforeEach(function () {
        image = React.createElement("img", { src: "404.jpg", alt: "", role: "presentation" });
        title = React.createElement("div", { className: "TITLE" }, "TITLE CONTENT");
        metadata = React.createElement("div", { className: "METADATA" }, "METADATA CONTENT");
        extra = React.createElement("div", { className: "EXTRA" }, "EXTRA CONTENT");
        children = React.createElement("div", { className: "CHILDREN" }, "CHILDREN CONTENT");
    });
    describe('with minimal options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.MediaObjectSize.MEDIUM }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.MediaObjectSize.MEDIUM, className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with image content', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.MediaObjectSize.MEDIUM, imageContent: image }));
            component.render();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with title content', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.MediaObjectSize.MEDIUM, titleContent: title }));
            component.render();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('with allowTextWrap', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { allowTextWrap: true, size: _1.MediaObjectSize.MEDIUM, titleContent: title }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with metadata content', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.MediaObjectSize.MEDIUM, metadataContent: metadata }));
            component.render();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('at extra small size', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.MediaObjectSize.XSMALL, metadataContent: metadata }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with allowTextWrap', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { allowTextWrap: true, size: _1.MediaObjectSize.MEDIUM, metadataContent: metadata }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with extra content', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.MediaObjectSize.MEDIUM, extraContent: extra }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('at extra large size', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.MediaObjectSize.XLARGE, extraContent: extra }));
                component.render();
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with allowTextWrap', function () {
            beforeEach(function () {
                component = enzyme_1.shallow(React.createElement(_1.default, { allowTextWrap: true, size: _1.MediaObjectSize.XLARGE, extraContent: extra }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with arbitrary children', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { size: _1.MediaObjectSize.MEDIUM }, children));
            component.render();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=MediaObject.test.js.map