"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
require("../../yamui");
var React = require("react");
var classNames_1 = require("../../util/classNames");
var Icon_1 = require("../Icon");
var Block_1 = require("../Block");
var Text_1 = require("../Text");
var FixedGrid_1 = require("../FixedGrid");
var ContextualMenu_1 = require("office-ui-fabric-react/lib/ContextualMenu");
var getClasses = function (isHeader) {
    var classes = ['y-menu-button--item'];
    if (isHeader) {
        classes.push('y-menu-button--item-header');
    }
    return classNames_1.join(classes);
};
var getIconClasses = function (isDisabled) {
    var classes = ['y-menu-button--item-icon'];
    if (isDisabled) {
        classes.push('y-menu-button--item-icon__disabled');
    }
    return classNames_1.join(classes);
};
var getIconColumn = function (data, disabled) {
    var Icon = data && data.yamUIIcon;
    var Illustration = data && data.yamUIIllustration;
    if (Icon) {
        return (React.createElement(FixedGrid_1.FixedGridColumn, { fixed: true, className: getIconClasses(disabled) },
            React.createElement(Icon, { size: Icon_1.IconSize.MEDIUM, block: true })));
    }
    else if (Illustration) {
        return (React.createElement(FixedGrid_1.FixedGridColumn, { fixed: true, className: "y-menu-button--item-icon" },
            React.createElement(Illustration, { block: true })));
    }
    else {
        return null;
    }
};
var MenuButtonItem = function (props) {
    var _a = props.item, data = _a.data, name = _a.name, itemType = _a.itemType, _b = _a.disabled, disabled = _b === void 0 ? false : _b;
    var isHeader = itemType === ContextualMenu_1.ContextualMenuItemType.Header;
    var color = Block_1.TextColor.SECONDARY;
    if (isHeader) {
        color = Block_1.TextColor.PRIMARY;
    }
    else if (disabled) {
        color = Block_1.TextColor.DISABLED;
    }
    var size = isHeader ? Text_1.TextSize.SMALL : Text_1.TextSize.MEDIUM_SUB;
    return (React.createElement(Block_1.default, { textColor: color, textSize: size, className: getClasses(isHeader) },
        React.createElement(FixedGrid_1.FixedGridRow, { gutterSize: FixedGrid_1.GutterSize.SMALL },
            getIconColumn(data, disabled),
            React.createElement(FixedGrid_1.FixedGridColumn, { className: "y-menu-button--item-text" }, name))));
};
exports.default = MenuButtonItem;
//# sourceMappingURL=MenuButtonItem.js.map