"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var _1 = require(".");
var test_utils_1 = require("react-dom/test-utils");
describe('<NavigationLink />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { href: "test.html" }, "link content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when unstyled', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { href: "test.html", unstyled: true }, "link content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with ariaCurrent', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { href: "test.html", ariaCurrent: "page" }, "link content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with ariaLabel', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { href: "test.html", ariaLabel: "ARIA LABEL CONTENT" }, "link content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with title', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { href: "test.html", title: "TITLE CONTENT" }, "link content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when newWindow is true', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { href: "test.html", newWindow: true }, "link content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { href: "test.html", className: "TEST_CLASSNAME" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with block={true}', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { href: "test.html", block: true }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when focusableRef is passed', function () {
        var anchor;
        var focusable;
        beforeEach(function () {
            var setFocusable = function (f) {
                focusable = f;
            };
            var rendered = test_utils_1.renderIntoDocument(React.createElement(_1.default, { href: "test.html", focusableRef: setFocusable }, "test content"));
            anchor = test_utils_1.findRenderedDOMComponentWithClass(rendered, 'y-navigationLink');
        });
        it('matches its snapshot', function () {
            expect(anchor).toMatchSnapshot();
        });
        describe('when focusable is used', function () {
            beforeEach(function () {
                jest.spyOn(anchor, 'focus');
                focusable.focus();
            });
            it('calls focus on underlying button', function () {
                expect(anchor.focus).toHaveBeenCalledTimes(1);
            });
        });
    });
});
//# sourceMappingURL=NavigationLink.test.js.map