"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var Clickable_1 = require("../Clickable");
var EditableText_1 = require("../EditableText");
var index_1 = require("./index");
var test_utils_1 = require("react-dom/test-utils");
describe('<PreviewCard />', function () {
    var component;
    var onClick;
    var onChange;
    describe('with minimal options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { name: "Filename.gif" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with description', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { name: "Filename.gif", description: "file description" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when description is edible', function () {
        describe('with onDescriptionChange callback', function () {
            var jsxComponent;
            var testComponent;
            beforeEach(function () {
                onChange = jest.fn();
                jsxComponent = (React.createElement(index_1.default, { name: "Filename.gif", description: "file description", isDescriptionEditable: true, descriptionMaxLength: 120, emptyEditableDescriptionText: "empty placeholder text", onDescriptionChange: onChange }));
            });
            it('matches its snapshot', function () {
                expect(enzyme_1.shallow(jsxComponent)).toMatchSnapshot();
            });
            describe('when entering edit mode', function () {
                beforeEach(function () {
                    var renderedPreviewCard = test_utils_1.renderIntoDocument(jsxComponent);
                    var renderedEditableText = test_utils_1.findRenderedComponentWithType(renderedPreviewCard, EditableText_1.default);
                    renderedEditableText.props.onBeginEditing();
                    testComponent = test_utils_1.findRenderedComponentWithType(renderedPreviewCard, index_1.default).render();
                });
                it('matches its snapshot', function () {
                    expect(testComponent).toMatchSnapshot();
                });
            });
            describe('when exiting edit mode', function () {
                beforeEach(function () {
                    var renderedPreviewCard = test_utils_1.renderIntoDocument(jsxComponent);
                    var renderedEditableText = test_utils_1.findRenderedComponentWithType(renderedPreviewCard, EditableText_1.default);
                    renderedEditableText.props.onEndEditing();
                    testComponent = test_utils_1.findRenderedComponentWithType(renderedPreviewCard, index_1.default).render();
                });
                it('matches its snapshot', function () {
                    expect(testComponent).toMatchSnapshot();
                });
            });
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { name: "Filename.gif", className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with image', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { name: "Filename.gif", imageUrl: "filename.png", imageDescription: "file description" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when loading', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { name: "Filename.gif", isLoading: true, loadingText: "loading..." }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with loading progress', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { name: "Filename.gif", isLoading: true, loadingText: "Uploading, currently at 50%", progress: 0.5 }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with onClick handler', function () {
        beforeEach(function () {
            onClick = jest.fn();
            component = enzyme_1.shallow(React.createElement(index_1.default, { name: "Filename.gif", onClick: onClick, clickAriaLabel: "Show file preview" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('when clicked', function () {
            beforeEach(function () {
                component.simulate('click');
            });
            it('triggers the onClick callback prop', function () {
                expect(onClick).toHaveBeenCalledTimes(1);
            });
        });
    });
    describe('with onRemoveClick handler', function () {
        beforeEach(function () {
            onClick = jest.fn();
            component = enzyme_1.shallow(React.createElement(index_1.default, { name: "Filename.gif", onRemoveClick: onClick, removeAriaLabel: "Remove this attachment" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('when the remove button is clicked', function () {
            beforeEach(function () {
                var onRemoveClick = component.find(Clickable_1.default).prop('onClick');
                onRemoveClick({ stopPropagation: function () { return undefined; } });
            });
            it('triggers the onRemoveClick callback prop', function () {
                expect(onClick).toHaveBeenCalledTimes(1);
            });
        });
    });
});
//# sourceMappingURL=PreviewCard.test.js.map