"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var _1 = require(".");
describe('<SuggestionsList />', function () {
    var rendered;
    var onItemSelected;
    var options;
    var getProps = function (overrides) {
        onItemSelected = jest.fn();
        var defaultProps = {
            onItemSelected: onItemSelected,
            searchText: 'searchText',
            loadingText: 'loadingText',
            noResultsText: 'noResultsText',
            isLoading: false,
            groupedItems: [],
            selectedId: 2,
        };
        return __assign({}, defaultProps, overrides);
    };
    beforeEach(function () {
        options = {};
    });
    describe('when isLoading=true', function () {
        beforeEach(function () {
            options = __assign({}, options, { isLoading: true });
        });
        describe('without results', function () {
            beforeEach(function () {
                rendered = enzyme_1.shallow(React.createElement(_1.default, __assign({}, getProps(options))));
            });
            it('renders as expected', function () {
                expect(rendered).toMatchSnapshot();
            });
        });
        describe('with results', function () {
            beforeEach(function () {
                options = __assign({}, options, { groupedItems: [
                        {
                            title: 'groupTitle',
                            items: [
                                {
                                    id: 'id',
                                    imageUrl: 'imageUrl',
                                    name: 'name',
                                    description: 'description',
                                },
                            ],
                        },
                    ] });
                rendered = enzyme_1.shallow(React.createElement(_1.default, __assign({}, getProps(options))));
            });
            it('renders as expected', function () {
                expect(rendered).toMatchSnapshot();
            });
            describe('when onHover is called', function () {
                beforeEach(function () {
                    rendered.find('SuggestionsListItem').simulate('hover', '1');
                });
                it('updates the state', function () {
                    expect(rendered.state()).toMatchSnapshot();
                });
            });
            describe('with state.hoveredId=id', function () {
                beforeEach(function () {
                    rendered.setState({ hoveredId: 'id' });
                });
                it('renders as expected', function () {
                    expect(rendered).toMatchSnapshot();
                });
                describe('when the mouse leaves', function () {
                    beforeEach(function () {
                        rendered
                            .find('ul')
                            .at(1)
                            .simulate('mouseLeave');
                    });
                    it('renders as expected', function () {
                        expect(rendered).toMatchSnapshot();
                    });
                });
            });
        });
    });
    describe('when isLoading=false', function () {
        beforeEach(function () {
            options = __assign({}, options, { isLoading: false });
        });
        describe('without results', function () {
            beforeEach(function () {
                rendered = enzyme_1.shallow(React.createElement(_1.default, __assign({}, getProps(options))));
            });
            it('renders as expected', function () {
                expect(rendered).toMatchSnapshot();
            });
        });
        describe('with results', function () {
            beforeEach(function () {
                options = __assign({}, options, { groupedItems: [
                        {
                            title: 'groupTitle',
                            items: [
                                {
                                    id: 'id',
                                    imageUrl: 'imageUrl',
                                    name: 'name',
                                    description: 'description',
                                },
                            ],
                        },
                    ] });
                rendered = enzyme_1.shallow(React.createElement(_1.default, __assign({}, getProps(options))));
            });
            it('renders as expected', function () {
                expect(rendered).toMatchSnapshot();
            });
            describe('when onHover is called', function () {
                beforeEach(function () {
                    rendered.find('SuggestionsListItem').simulate('hover', '1');
                });
                it('updates the state', function () {
                    expect(rendered.state()).toMatchSnapshot();
                });
            });
            describe('with state.hoveredId=id', function () {
                beforeEach(function () {
                    rendered.setState({ hoveredId: 'id' });
                });
                it('renders as expected', function () {
                    expect(rendered).toMatchSnapshot();
                });
                describe('when the mouse leaves', function () {
                    beforeEach(function () {
                        rendered
                            .find('ul')
                            .at(1)
                            .simulate('mouseLeave');
                    });
                    it('renders as expected', function () {
                        expect(rendered).toMatchSnapshot();
                    });
                });
            });
        });
    });
});
//# sourceMappingURL=SuggestionsList.test.js.map