"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var test_utils_1 = require("react-dom/test-utils");
var _1 = require(".");
var render = function (jsx) {
    var renderedText = test_utils_1.renderIntoDocument(jsx);
    return test_utils_1.findRenderedDOMComponentWithClass(renderedText, 'y-text');
};
describe('<Text />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, null, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { className: "TEST_CLASSNAME" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with a valid size', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { size: _1.TextSize.XLARGE }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with a valid size and maxWidth', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { size: _1.TextSize.XLARGE, maxWidth: "200px" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with bold', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { bold: true }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with uppercase', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { uppercase: true }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with maxWidth 500px', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { maxWidth: "500px" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with color secondary', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { color: _1.TextColor.SECONDARY }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with screenreader text', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { screenreaderText: "SCREENREADER TEXT" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with screenreader text empty string', function () {
        beforeEach(function () {
            component = render(React.createElement(_1.default, { screenreaderText: "" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=Text.test.js.map