"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var _1 = require(".");
var TextField_1 = require("office-ui-fabric-react/lib/TextField");
describe('<TextField />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, null))
                .dive()
                .dive()
                .dive();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with all options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.default, { ariaLabel: "ARIA_LABEL", prefix: "PREFIX", suffix: "SUFFIX", maxLength: 100, underlined: true, className: "CLASS", value: "VALUE", label: "LABEL", description: "DESCRIPTION", disabled: true, required: true, errorMessage: "ERROR MESSAGE", placeHolder: "PLACEHOLDER", onFocus: jest.fn().mockName('onFocus'), onBlur: jest.fn().mockName('onBlur'), onMouseEnter: jest.fn().mockName('onMouseEnter'), onMouseLeave: jest.fn().mockName('onMouseLeave'), focusableRef: jest.fn().mockName('focusableRef') }))
                .dive()
                .dive()
                .dive();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('mounted with default options', function () {
        var focusable;
        var setFocusable = function (f) { return (focusable = f); };
        describe('when focused', function () {
            var focusSpy;
            var setSelectionRangeSpy;
            beforeEach(function () {
                focusSpy = jest.spyOn(TextField_1.TextField.prototype, 'focus');
                setSelectionRangeSpy = jest.spyOn(TextField_1.TextField.prototype, 'setSelectionRange');
                enzyme_1.mount(React.createElement(_1.default, { focusableRef: setFocusable }));
                focusable.focus();
            });
            it('calls focus', function () {
                expect(focusSpy).toHaveBeenCalled();
            });
            it('calls setSelectionRangeSpy', function () {
                expect(setSelectionRangeSpy).toHaveBeenCalledWith(0, 0);
            });
        });
    });
    describe('when mounted', function () {
        var value = 'VALUE';
        var focusable;
        var setFocusable = function (f) { return (focusable = f); };
        beforeEach(function () {
            enzyme_1.mount(React.createElement(_1.default, { value: value, description: "DESCRIPTION", focusableRef: setFocusable }));
        });
        describe('and its public focus() method is called', function () {
            var focusSpy;
            var setSelectionRangeSpy;
            beforeEach(function () {
                focusSpy = jest.spyOn(TextField_1.TextField.prototype, 'focus');
                setSelectionRangeSpy = jest.spyOn(TextField_1.TextField.prototype, 'setSelectionRange');
                focusable.focus();
            });
            it('focuses the interal textfield', function () {
                expect(focusSpy).toHaveBeenCalled();
            });
            it('places the cursor at the end of the input text', function () {
                expect(setSelectionRangeSpy).toHaveBeenCalledWith(value.length, value.length);
            });
        });
    });
});
//# sourceMappingURL=TextField.test.js.map