/// <reference types="react" />
import '../../../yamui';
import * as React from 'react';
import { DebouncedOnChangeProps, DebouncedOnChangePrivateProps } from '../../../util/DebouncedOnChange';
import { BaseComponentProps, FocusableComponentProps } from '../../../util/BaseComponent/props';
import './TextField.css';
export interface BaseTextFieldProps extends BaseComponentProps, FocusableComponentProps, DebouncedOnChangeProps, DebouncedOnChangePrivateProps {
    /**
     * aria-label attribute
     */
    ariaLabel?: string;
    /**
     * Current value of the textfield.
     */
    value?: string;
    /**
     * Placeholder text. Displayed until a value is entered.
     */
    placeHolder?: string;
    /**
     * Error message string.
     */
    errorMessage?: string;
    /**
     * Disabled state of the textfield.
     */
    disabled?: boolean;
    /**
     * Label for the textfield.
     */
    label?: string;
    /**
     * The textfield input description
     */
    description?: string | JSX.Element;
    /**
     * Use to indicate that a value must be provided to allow the containing form to be submitted.
     */
    required?: boolean;
    /**
     * Use as the input's maxLength attribute.
     */
    maxLength?: number;
    /**
     * Callback for the onChanged event.
     */
    onChange?: ((newValue: any) => void);
    /**
     * Focus callback handler.
     */
    onFocus?: ((event: React.FocusEvent<HTMLInputElement | HTMLTextAreaElement>) => void);
    /**
     * Blur callback handler.
     */
    onBlur?: ((event: React.FocusEvent<HTMLInputElement | HTMLTextAreaElement>) => void);
    /**
     * Mouse enter callback handler.
     */
    onMouseEnter?: ((event: React.MouseEvent<HTMLInputElement | HTMLTextAreaElement>) => void);
    /**
     * Mouse leave callback handler.
     */
    onMouseLeave?: ((event: React.MouseEvent<HTMLInputElement | HTMLTextAreaElement>) => void);
    /**
     * Key press handler, cancelable before text is entered.
     */
    onKeyDown?: ((event: React.KeyboardEvent<HTMLInputElement | HTMLTextAreaElement>) => void);
}
export interface SingleLineTextFieldProps {
    multiline: false;
    /**
     * String for prefix.
     */
    prefix?: string;
    /**
     * String for suffix.
     */
    suffix?: string;
    /**
     * Whether or not the textfield is underlined.
     */
    underlined?: boolean;
}
export interface MultiLineTextFieldProps {
    multiline: true;
    /**
     * Height of the field, in number of rows.
     */
    rows?: number;
    /**
     * Whether or not to auto adjust textField height.
     */
    autoAdjustHeight?: boolean;
}
export declare type TextInputProps = BaseTextFieldProps & SingleLineTextFieldProps;
export declare type TextAreaProps = BaseTextFieldProps & MultiLineTextFieldProps;
export declare type TextFieldProps = TextInputProps | TextAreaProps;
declare const _default: (props: TextFieldProps) => JSX.Element;
export default _default;
