"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var Utilities_1 = require("office-ui-fabric-react/lib/Utilities");
var keyCodes_1 = require("../keyCodes");
/**
 * A class which listens to page-level mouse/keyboard events and manages callback subscriptions.
 * This should be exposed as a singleton via './keyboardNavigation.ts', do not import this class directly.
 */
var KeyboardNavigationEventListener = /** @class */ (function () {
    function KeyboardNavigationEventListener(element) {
        var _this = this;
        this.onMouseDown = function () {
            if (_this.mode !== 'mouse') {
                _this.mode = 'mouse';
                _this.eventGroup.raise('modeChange', _this.mode);
            }
        };
        this.onKeyDown = function (event) {
            if (keyCodes_1.directionalKeyCodes.indexOf(event.which) > -1) {
                _this.mode = 'keyboard';
                _this.eventGroup.raise('modeChange', _this.mode);
            }
        };
        this.element = element;
        this.mode = 'mouse';
        this.eventGroup = new Utilities_1.EventGroup(this);
        this.eventGroup.on(this.element, 'mousedown', this.onMouseDown, true);
        this.eventGroup.on(this.element, 'keydown', this.onKeyDown, true);
    }
    KeyboardNavigationEventListener.prototype.getMode = function () {
        return this.mode;
    };
    KeyboardNavigationEventListener.prototype.destroy = function () {
        this.eventGroup.off();
    };
    KeyboardNavigationEventListener.prototype.subscribe = function (callback) {
        this.eventGroup.on(this, 'modeChange', callback);
    };
    KeyboardNavigationEventListener.prototype.unsubscribe = function (callback) {
        this.eventGroup.off(this, 'modeChange', callback);
    };
    return KeyboardNavigationEventListener;
}());
exports.default = KeyboardNavigationEventListener;
//# sourceMappingURL=KeyboardNavigationEventListener.js.map