/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import ActionLink from './index';
import Down from '../Icon/icons/Down';
describe('<ActionLink />', function () {
    var component;
    describe('with href', function () {
        beforeEach(function () {
            component = shallow(React.createElement(ActionLink, { text: "Download", icon: Down, href: "https://yammer.com", newWindow: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with href and ariaLabel', function () {
        beforeEach(function () {
            component = shallow(React.createElement(ActionLink, { text: "Download", icon: Down, ariaLabel: "Download file", href: "https://yammer.com", newWindow: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with onClick', function () {
        var onClick;
        beforeEach(function () {
            onClick = jest.fn();
            component = shallow(React.createElement(ActionLink, { text: "Download", icon: Down, onClick: onClick }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('when clicked', function () {
            beforeEach(function () {
                component.simulate('click');
            });
            it('calls props.onClick', function () {
                expect(onClick).toHaveBeenCalledTimes(1);
            });
        });
    });
    describe('with onClick and ariaLabel', function () {
        var onClick;
        beforeEach(function () {
            onClick = jest.fn();
            component = shallow(React.createElement(ActionLink, { text: "Download", ariaLabel: "Download file", icon: Down, onClick: onClick }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = shallow(React.createElement(ActionLink, { className: "TEST_CLASSNAME", text: "Download", icon: Down, ariaLabel: "Download the file", href: "https://yammer.com" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=ActionLink.test.js.map