/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import Text from '../Text';
import Avatar, { AvatarSize, BorderType } from '.';
describe('<Avatar />', function () {
    var component;
    describe('with image url', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Avatar, { name: "NAME", imageUrl: "test.jpg" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with too many characters', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Avatar, { name: "First Last" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with badge content', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Avatar, { name: "NAME", imageUrl: "test.jpg", size: AvatarSize.XSMALL, badgeContent: React.createElement(Text, null, "badge") }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with soft border type', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Avatar, { name: "NAME", imageUrl: "test.jpg", borderType: BorderType.SOFT }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with size', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Avatar, { name: "NAME", imageUrl: "test.jpg", size: AvatarSize.XLARGE }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Avatar, { name: "NAME", imageUrl: "test.jpg", className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('accessible text', function () {
        describe('without badge description', function () {
            beforeEach(function () {
                component = shallow(React.createElement(Avatar, { name: "NAME", imageUrl: "test.jpg" }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with badge description', function () {
            beforeEach(function () {
                component = shallow(React.createElement(Avatar, { name: "NAME", imageUrl: "test.jpg", badgeDescription: "BADGE" }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
});
//# sourceMappingURL=Avatar.test.js.map