/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { create as createRenderer } from 'react-test-renderer';
import { renderIntoDocument, findRenderedDOMComponentWithClass } from 'react-dom/test-utils';
import Block, { GutterSize, TextColor, TextSize } from '.';
import Clickable from '../Clickable';
var render = function (jsx) {
    return createRenderer(jsx).toJSON();
};
describe('<Block />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, null, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { className: "TEST_CLASSNAME" }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with xLarge text size', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { textSize: TextSize.XLARGE }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with secondary textColor', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { textColor: TextColor.SECONDARY }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with textAlign', function () {
        describe('right', function () {
            beforeEach(function () {
                component = render(React.createElement(Block, { textAlign: "right" }, "block content"));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('center', function () {
            beforeEach(function () {
                component = render(React.createElement(Block, { textAlign: "center" }, "block content"));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with ellipsis', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { ellipsis: true }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with top spacing', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { topSpacing: GutterSize.SMALL }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with bottom spacing', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { bottomSpacing: GutterSize.XLARGE }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with padding', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { padding: GutterSize.SMALL }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with horizontal padding', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { horizontalPadding: GutterSize.MEDIUM }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with vertical padding', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { verticalPadding: GutterSize.XLARGE }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with positive push', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { push: 3 }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with negative push', function () {
        beforeEach(function () {
            component = render(React.createElement(Block, { push: -2 }, "block content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('within clickable', function () {
        var rendered;
        beforeEach(function () {
            rendered = renderIntoDocument(React.createElement(Clickable, null,
                React.createElement(Block, null, "block content")));
        });
        it('matches its snapshot', function () {
            expect(findRenderedDOMComponentWithClass(rendered, 'y-block')).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=Block.test.js.map