/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import Box from './index';
describe('<Box />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Box, null));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Box, { className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with children passed', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Box, null));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with onClick', function () {
        var onClick;
        beforeEach(function () {
            onClick = jest.fn();
            component = shallow(React.createElement(Box, { onClick: onClick }, "click me"));
        });
        describe('when clicked', function () {
            beforeEach(function () {
                component.simulate('click');
            });
            it('triggers the onClick callback', function () {
                expect(onClick).toHaveBeenCalledTimes(1);
            });
        });
    });
});
//# sourceMappingURL=Box.test.js.map