var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import { BistateButton } from '.';
describe('<BistateButton />', function () {
    var component;
    var getProps = function () {
        return {
            text: 'Joined',
            activeProps: {
                text: 'Leave',
            },
        };
    };
    beforeEach(function () {
        component = shallow(React.createElement(BistateButton, __assign({}, getProps())));
    });
    it('matches its snapshot', function () {
        expect(component).toMatchSnapshot();
    });
    describe('when mouse enters', function () {
        beforeEach(function () {
            component.simulate('mouseEnter');
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('when blurs', function () {
            beforeEach(function () {
                component.simulate('blur');
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('when mouse leaves', function () {
            beforeEach(function () {
                component.simulate('mouseLeave');
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('when focuses', function () {
        beforeEach(function () {
            component.simulate('focus');
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('when mouse leaves', function () {
            beforeEach(function () {
                component.simulate('mouseLeave');
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('when blurs', function () {
            beforeEach(function () {
                component.simulate('blur');
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with an onMouseEnter prop', function () {
        var onMouseEnter;
        beforeEach(function () {
            onMouseEnter = jest.fn();
            component = shallow(React.createElement(BistateButton, __assign({}, getProps(), { onMouseEnter: onMouseEnter })));
        });
        describe('when the mouse enters', function () {
            beforeEach(function () {
                component.simulate('mouseEnter');
            });
            it('calls onMouseEnter', function () {
                expect(onMouseEnter).toBeCalled();
            });
        });
    });
    describe('with an onMouseLeave prop', function () {
        var onMouseLeave;
        beforeEach(function () {
            onMouseLeave = jest.fn();
            component = shallow(React.createElement(BistateButton, __assign({}, getProps(), { onMouseLeave: onMouseLeave })));
        });
        describe('when the mouse leaves', function () {
            beforeEach(function () {
                component.simulate('mouseLeave');
            });
            it('calls onMouseLeave', function () {
                expect(onMouseLeave).toBeCalled();
            });
        });
    });
    describe('with an onFocus prop', function () {
        var onFocus;
        beforeEach(function () {
            onFocus = jest.fn();
            component = shallow(React.createElement(BistateButton, __assign({}, getProps(), { onFocus: onFocus })));
        });
        describe('when focusing', function () {
            beforeEach(function () {
                component.simulate('focus');
            });
            it('calls onFocus', function () {
                expect(onFocus).toBeCalled();
            });
        });
    });
    describe('with an onBlur prop', function () {
        var onBlur;
        beforeEach(function () {
            onBlur = jest.fn();
            component = shallow(React.createElement(BistateButton, __assign({}, getProps(), { onBlur: onBlur })));
        });
        describe('when blurring', function () {
            beforeEach(function () {
                component.simulate('blur');
            });
            it('calls onBlur', function () {
                expect(onBlur).toBeCalled();
            });
        });
    });
});
//# sourceMappingURL=BistateButton.test.js.map