var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import '../../yamui';
import * as React from 'react';
import { BaseButton } from 'office-ui-fabric-react/lib/components/Button/BaseButton';
import Block, { TextSize } from '../Block';
import Spinner, { SpinnerColor, SpinnerSize } from '../Spinner';
import { ButtonColor, ButtonStatus, ButtonIconPosition, ButtonSize, ButtonType } from './types';
import { getStyles } from './Button.styles';
import './Button.css';
export { ButtonColor, ButtonStatus, ButtonIconPosition, ButtonSize, ButtonType };
var hrefBlacklist = ['', '#', 'javascript://'];
/**
 * A `Button` allows a user to take an action.
 */
var Button = /** @class */ (function (_super) {
    __extends(Button, _super);
    function Button() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Button.prototype.render = function () {
        var _a = this.props, ariaLabel = _a.ariaLabel, type = _a.type, onClick = _a.onClick, onFocus = _a.onFocus, onBlur = _a.onBlur, onMouseEnter = _a.onMouseEnter, onMouseLeave = _a.onMouseLeave, className = _a.className;
        var href = this.props.href;
        var newWindow = this.props.newWindow;
        var target = newWindow ? '_blank' : undefined;
        var status = this.props.status;
        var isDisabled = status === ButtonStatus.DISABLED || status === ButtonStatus.LOADING;
        return (React.createElement(BaseButton, { ariaLabel: ariaLabel, className: "y-button " + (className ? className : ''), disabled: isDisabled, href: href, target: target, type: href ? '' : type, onBlur: onBlur, onClick: onClick, onFocus: onFocus, onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave, styles: getStyles(this.props) },
            this.getContents(),
            this.isLoading() && this.getSpinner()));
    };
    Button.prototype.getContents = function () {
        var _a = this.props, Icon = _a.icon, iconPosition = _a.iconPosition, size = _a.size, text = _a.text, secondaryText = _a.secondaryText;
        var textSize = size === ButtonSize.SMALL ? TextSize.SMALL : TextSize.MEDIUM_SUB;
        var buttonIcon = Icon && (React.createElement("span", { className: "y-button--icon-wrapper-" + iconPosition },
            React.createElement(Icon, null)));
        var className = this.isLoading() ? 'y-button--content__hidden' : '';
        var leftIcon = iconPosition === 'left' && buttonIcon;
        var rightIcon = iconPosition === 'right' && buttonIcon;
        return (React.createElement(Block, { textSize: textSize, className: className, textAlign: "center" },
            leftIcon,
            text,
            rightIcon,
            React.createElement("div", { className: "y-button--secondary-text" },
                leftIcon,
                secondaryText,
                rightIcon)));
    };
    Button.prototype.getSpinner = function () {
        var _a = this.props, color = _a.color, size = _a.size;
        var loadingText = this.props.loadingText;
        var spinnerColor = color === ButtonColor.PRIMARY ? SpinnerColor.DARK : SpinnerColor.LIGHT;
        var spinnerSize = size === ButtonSize.SMALL ? SpinnerSize.XSMALL : SpinnerSize.SMALL;
        return (React.createElement("span", { className: "y-button--spinner" },
            React.createElement(Spinner, { color: spinnerColor, size: spinnerSize, text: loadingText, hideText: true, isCentered: true })));
    };
    Button.prototype.isLoading = function () {
        return this.props.status === ButtonStatus.LOADING;
    };
    Button.propTypes = {
        // TypeScript does not support negated types, so we need to do a runtime validation instead.
        href: function (props, propName, componentName) {
            var href = props.href;
            if (typeof href !== 'string') {
                return;
            }
            if (hrefBlacklist.indexOf(href) > -1) {
                return new Error("Invalid prop " + propName + " supplied to " + componentName + ": \"" + href + "\".\n          Please use a Button for actions, NavigationLink (or Button with href) for navigation.");
            }
        },
    };
    Button.defaultProps = {
        color: ButtonColor.SECONDARY,
        iconPosition: ButtonIconPosition.LEFT,
        size: ButtonSize.REGULAR,
        status: ButtonStatus.ENABLED,
        type: ButtonType.BUTTON,
    };
    return Button;
}(React.Component));
export default Button;
//# sourceMappingURL=Button.js.map