/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import Clickable from '.';
import { create as createRenderer } from 'react-test-renderer';
import { renderIntoDocument, Simulate, findRenderedDOMComponentWithClass } from 'react-dom/test-utils';
var render = function (jsx) {
    return createRenderer(jsx).toJSON();
};
describe('<Clickable />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = render(React.createElement(Clickable, null, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = render(React.createElement(Clickable, { className: "TEST_CLASSNAME" }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when unstyled', function () {
        beforeEach(function () {
            component = render(React.createElement(Clickable, { unstyled: true }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when block is true', function () {
        beforeEach(function () {
            component = render(React.createElement(Clickable, { block: true }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when title is passed', function () {
        beforeEach(function () {
            component = render(React.createElement(Clickable, { title: "extra browser tooltip content" }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when ariaLabel is passed', function () {
        beforeEach(function () {
            component = render(React.createElement(Clickable, { ariaLabel: "aria label content" }, "clickable content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when focusableRef is passed', function () {
        var button;
        var focusable;
        beforeEach(function () {
            var setFocusable = function (f) {
                focusable = f;
            };
            var rendered = renderIntoDocument(React.createElement(Clickable, { focusableRef: setFocusable }, "clickable content"));
            button = findRenderedDOMComponentWithClass(rendered, 'y-clickable');
        });
        it('matches its snapshot', function () {
            expect(button).toMatchSnapshot();
        });
        describe('when focusable is used', function () {
            beforeEach(function () {
                jest.spyOn(button, 'focus');
                focusable.focus();
            });
            it('calls focus on underlying button', function () {
                expect(button.focus).toHaveBeenCalledTimes(1);
            });
        });
    });
    describe('when clicked', function () {
        var clicked;
        var renderedDOM;
        function clickMe() {
            clicked = true;
        }
        beforeEach(function () {
            clicked = false;
            var renderedInstance = renderIntoDocument(React.createElement(Clickable, { onClick: clickMe }, "clickable content"));
            renderedDOM = findRenderedDOMComponentWithClass(renderedInstance, 'y-clickable');
        });
        it('triggers its onClick callback', function () {
            Simulate.click(renderedDOM);
            expect(clicked).toBe(true);
        });
    });
});
//# sourceMappingURL=Clickable.test.js.map