/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import { FixedGridColumn } from '.';
describe('<FixedGridColumn />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = shallow(React.createElement(FixedGridColumn, null, "grid content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = shallow(React.createElement(FixedGridColumn, { className: "TEST_CLASSNAME" }, "grid content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when set to fixed', function () {
        beforeEach(function () {
            component = shallow(React.createElement(FixedGridColumn, { fixed: true }, "grid content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when set to fixed and given a width', function () {
        beforeEach(function () {
            component = shallow(React.createElement(FixedGridColumn, { fixed: true, width: 150 }, "grid content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when given a width but not fixed', function () {
        beforeEach(function () {
            component = shallow(React.createElement(FixedGridColumn, { width: 150 }, "grid content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with vertical align middle', function () {
        beforeEach(function () {
            component = shallow(React.createElement(FixedGridColumn, { verticalAlign: "middle" }, "grid content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=FixedGridColumn.test.js.map