var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import '../../yamui';
import * as React from 'react';
import Block, { TextSize, GutterSize } from '../Block';
import './Heading.css';
var blockPropsMap = {
    1: {
        textSize: TextSize.XXLARGE,
        bottomSpacing: GutterSize.SMALL,
    },
    2: {
        textSize: TextSize.XLARGE,
        bottomSpacing: GutterSize.SMALL,
    },
    3: {
        textSize: TextSize.LARGE,
        bottomSpacing: GutterSize.MEDIUM,
    },
    4: {
        textSize: TextSize.LARGE,
        bottomSpacing: GutterSize.MEDIUM,
    },
    5: {
        textSize: TextSize.MEDIUM,
        bottomSpacing: GutterSize.MEDIUM,
    },
    6: {
        textSize: TextSize.MEDIUM_SUB,
        bottomSpacing: GutterSize.SMALL,
    },
};
/**
 * A `Heading` component renders an h1-h6 tag depending on the given level. You can also
 * override its visual styling to match a different level with `size`. Set `size="none"`
 * to render the heading as unstyled inline text.
 */
var Heading = /** @class */ (function (_super) {
    __extends(Heading, _super);
    function Heading() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Heading.prototype.render = function () {
        var TagName = "h" + this.props.level;
        return React.createElement(TagName, { className: this.getClasses() }, this.getSizedContent());
    };
    Heading.prototype.getSizedContent = function () {
        var _a = this.props, children = _a.children, level = _a.level, size = _a.size;
        if (size === 'none') {
            return children;
        }
        var visualSize = size || level;
        return React.createElement(Block, __assign({}, blockPropsMap[visualSize]), children);
    };
    Heading.prototype.getClasses = function () {
        var _a = this.props, className = _a.className, size = _a.size;
        var classes = ['y-heading'];
        if (size) {
            classes.push("y-heading__size-" + size);
        }
        if (className) {
            classes.push(className);
        }
        return classes.join(' ');
    };
    return Heading;
}(React.Component));
export default Heading;
//# sourceMappingURL=Heading.js.map