var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import '../../yamui';
import * as React from 'react';
import { join } from '../../util/classNames';
import Callout from '../Callout';
import ScreenreaderText from '../ScreenreaderText';
import './Hovercard.css';
var hideDelay = 500;
var showDelay = 750;
export var TriggerType;
(function (TriggerType) {
    TriggerType["CLICK"] = "click";
    TriggerType["HOVER"] = "hover";
})(TriggerType || (TriggerType = {}));
/**
 * A `Hovercard` is a small popover overlay. It opens on click or
 * mouse enter, and closes on mouse out and `ESC`. It should be used with `HovercardHeader` and
 * `HovercardBody` components for consistent internal padding.
 */
var Hovercard = /** @class */ (function (_super) {
    __extends(Hovercard, _super);
    function Hovercard(props) {
        var _this = _super.call(this, props) || this;
        _this.setRef = function (node) { return (_this.triggerElement = node); };
        _this.handleTriggerClick = function () {
            var triggerType = _this.props.triggerType;
            if (triggerType === TriggerType.CLICK) {
                _this.show();
            }
        };
        _this.handleTriggerHover = function () {
            var _a = _this.props, triggerType = _a.triggerType, onTriggerHover = _a.onTriggerHover;
            if (onTriggerHover) {
                onTriggerHover();
            }
            _this.cancelHide();
            if (triggerType === TriggerType.HOVER) {
                _this.beginShow();
            }
        };
        _this.handleTriggerHoverLeave = function () {
            _this.cancelShow();
            _this.beginHide();
        };
        _this.handleBodyHover = function () {
            _this.cancelHide();
        };
        _this.beginShow = function () {
            _this.showTimeout = window.setTimeout(function () {
                _this.show();
            }, showDelay);
        };
        _this.cancelShow = function () {
            if (_this.showTimeout) {
                window.clearTimeout(_this.showTimeout);
            }
        };
        _this.beginHide = function () {
            _this.hideTimeout = window.setTimeout(function () {
                _this.hide();
            }, hideDelay);
        };
        _this.cancelHide = function () {
            if (_this.hideTimeout) {
                window.clearTimeout(_this.hideTimeout);
            }
        };
        _this.show = function () {
            var onContentDisplay = _this.props.onContentDisplay;
            var visible = _this.state.visible;
            if (visible) {
                return;
            }
            if (onContentDisplay) {
                onContentDisplay();
            }
            //this.setState({ visible: true });
            _this.setState(function () { return ({ visible: true }); });
            _this.startKeyListener();
        };
        _this.hide = function () {
            var onContentDismiss = _this.props.onContentDismiss;
            var visible = _this.state.visible;
            if (!visible) {
                return;
            }
            if (onContentDismiss) {
                onContentDismiss();
            }
            _this.setState({ visible: false });
            _this.stopKeyListener();
        };
        _this.handleKeyDown = function (e) {
            if (e.keyCode === 27 /* escape */) {
                _this.hide();
            }
        };
        _this.startKeyListener = function () {
            document.addEventListener('keydown', _this.handleKeyDown);
        };
        _this.stopKeyListener = function () {
            document.removeEventListener('keydown', _this.handleKeyDown);
        };
        _this.triggerElement = null;
        _this.state = {
            visible: false,
        };
        return _this;
    }
    Hovercard.prototype.render = function () {
        var _a = this.props, className = _a.className, content = _a.content, directionalHint = _a.directionalHint, isBeakVisible = _a.isBeakVisible, screenreaderTitle = _a.screenreaderTitle, children = _a.children;
        var screenreaderTitleChild = screenreaderTitle && (React.createElement(ScreenreaderText, null,
            React.createElement("h1", null, screenreaderTitle)));
        var hovercard = this.state.visible && (React.createElement(Callout, { isBeakVisible: isBeakVisible, directionalHint: directionalHint, target: this.triggerElement, onDismiss: this.hide, preventDismissOnScroll: false },
            React.createElement("div", { className: "y-hovercard--modal-container", onMouseEnter: this.handleBodyHover, onMouseLeave: this.beginHide },
                screenreaderTitleChild,
                content)));
        return (React.createElement("span", { className: join(['y-hovercard', className]) },
            React.createElement("span", { className: "y-hovercard--trigger", ref: this.setRef, onClick: this.handleTriggerClick, onMouseEnter: this.handleTriggerHover, onMouseLeave: this.handleTriggerHoverLeave }, children),
            hovercard));
    };
    // Set initial visible state after mount so the trigger ref exists for positioning
    Hovercard.prototype.componentDidMount = function () {
        var startVisible = this.props.startVisible;
        if (startVisible) {
            this.show();
        }
    };
    Hovercard.prototype.componentWillUnmount = function () {
        if (this.showTimeout) {
            window.clearTimeout(this.showTimeout);
        }
        if (this.hideTimeout) {
            window.clearTimeout(this.hideTimeout);
        }
        this.stopKeyListener();
    };
    Hovercard.defaultProps = {
        directionalHint: 5 /* bottomCenter */,
        isBeakVisible: true,
        startVisible: false,
        triggerType: TriggerType.HOVER,
    };
    return Hovercard;
}(React.Component));
export default Hovercard;
//# sourceMappingURL=Hovercard.js.map