/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { mount, shallow } from 'enzyme';
import Image, { BorderType, ImageFit, ImageLoadState } from '.';
describe('<Image />', function () {
    var component;
    var fullComponent;
    describe('with default options', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Image, { source: "image.png", description: "description" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Image, { source: "image.png", description: "description", className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with height 50 and width 100', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Image, { source: "image.png", description: "description", height: 50, width: 100 }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with imageFit cover', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Image, { source: "image.png", description: "description", imageFit: ImageFit.cover }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with border type', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Image, { source: "image.png", description: "description", borderType: BorderType.ROUND }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with fullWidth', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Image, { source: "image.png", description: "description", fullWidth: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with fullWidth and height', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Image, { source: "image.png", description: "description", fullWidth: true, height: 50 }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with shouldFadeIn', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Image, { source: "image.png", description: "description", shouldFadeIn: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with block', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Image, { source: "image.png", description: "description", block: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when provided a loading state callback', function () {
        var loadState;
        function setLoadState(newLoadState) {
            loadState = newLoadState;
        }
        beforeEach(function () {
            jest.useFakeTimers();
            loadState = undefined;
            fullComponent = mount(React.createElement(Image, { source: "image.png", description: "description", onLoadingStateChange: setLoadState }));
        });
        it('triggers a callback with loaded status on load', function () {
            fullComponent.find('img').simulate('load');
            setTimeout(function () { }, 1);
            jest.runAllTimers();
            expect(loadState).toEqual(ImageLoadState.loaded);
        });
        it('triggers a callback with error status on error', function () {
            fullComponent.find('img').simulate('error');
            setTimeout(function () { }, 1);
            jest.runAllTimers();
            expect(loadState).toEqual(ImageLoadState.error);
        });
    });
});
//# sourceMappingURL=Image.test.js.map