var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import '../../yamui';
import * as React from 'react';
import { getMode, subscribe, unsubscribe, } from '../../util/accessibility/keyboardNavigation';
/**
 * KeyboardNavigationObserver allows for conditional child rendering and callbacks depending on whether the user
 * is currently navigating via mouse or keyboard. This is useful for features like infinite scroll, where
 * new pages should be loaded by button-click instead of scroll-based auto-loaded, ensuring keyboard navigation
 * users are able to navigate past the end of the content section and into footer or sidebar sections.
 */
var KeyboardNavigationObserver = /** @class */ (function (_super) {
    __extends(KeyboardNavigationObserver, _super);
    function KeyboardNavigationObserver(props) {
        var _this = _super.call(this, props) || this;
        _this.onModeChange = function (mode) {
            var _a = _this.props, onEnterKeyboardMode = _a.onEnterKeyboardMode, onEnterMouseMode = _a.onEnterMouseMode;
            if (mode === 'keyboard' && onEnterKeyboardMode) {
                onEnterKeyboardMode();
            }
            if (mode === 'mouse' && onEnterMouseMode) {
                onEnterMouseMode();
            }
            _this.setState({ mode: mode });
        };
        _this.state = {
            mode: getMode(),
        };
        return _this;
    }
    KeyboardNavigationObserver.prototype.render = function () {
        var _a = this.props, renderInKeyboardMode = _a.renderInKeyboardMode, renderInMouseMode = _a.renderInMouseMode;
        var mode = this.state.mode;
        if (mode === 'keyboard' && renderInKeyboardMode) {
            return renderInKeyboardMode();
        }
        if (mode === 'mouse' && renderInMouseMode) {
            return renderInMouseMode();
        }
        return null;
    };
    KeyboardNavigationObserver.prototype.componentDidMount = function () {
        subscribe(this.onModeChange);
    };
    KeyboardNavigationObserver.prototype.componentWillUnmount = function () {
        unsubscribe(this.onModeChange);
    };
    return KeyboardNavigationObserver;
}(React.Component));
export default KeyboardNavigationObserver;
//# sourceMappingURL=KeyboardNavigationObserver.js.map