/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { mount, shallow } from 'enzyme';
import KeyboardNavigationObserver from './index';
import * as keyboardNavigation from '../../util/accessibility/keyboardNavigation';
describe('<KeyboardNavigationObserver />', function () {
    var component;
    var mounted;
    var renderInKeyboardMode = function () { return React.createElement("span", null, "KEYBOARD"); };
    var renderInMouseMode = function () { return React.createElement("span", null, "MOUSE"); };
    var onEnterKeyboardModeCallback;
    var onEnterMouseModeCallback;
    beforeEach(function () {
        onEnterKeyboardModeCallback = jest.fn();
        onEnterMouseModeCallback = jest.fn();
    });
    afterEach(function () {
        jest.resetAllMocks();
    });
    describe('in mouse mode', function () {
        beforeEach(function () {
            jest.spyOn(keyboardNavigation, 'getMode').mockReturnValue('mouse');
        });
        describe('with minimal options', function () {
            beforeEach(function () {
                component = shallow(React.createElement(KeyboardNavigationObserver, null));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with all options', function () {
            beforeEach(function () {
                component = shallow(React.createElement(KeyboardNavigationObserver, { renderInKeyboardMode: renderInKeyboardMode, renderInMouseMode: renderInMouseMode, onEnterKeyboardMode: onEnterKeyboardModeCallback, onEnterMouseMode: onEnterMouseModeCallback }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('when mounted and mode is switched to keyboard', function () {
            beforeEach(function () {
                jest.spyOn(keyboardNavigation, 'subscribe').mockImplementation(function (callback) { return callback('keyboard'); });
                mounted = mount(React.createElement(KeyboardNavigationObserver, { renderInKeyboardMode: renderInKeyboardMode, renderInMouseMode: renderInMouseMode, onEnterKeyboardMode: onEnterKeyboardModeCallback, onEnterMouseMode: onEnterMouseModeCallback }));
            });
            afterEach(function () {
                if (mounted) {
                    mounted.unmount();
                }
            });
            it('triggers its onEnterKeyboardMode callback', function () {
                expect(onEnterKeyboardModeCallback).toHaveBeenCalled();
            });
            it('matches its snapshot', function () {
                expect(mounted).toMatchSnapshot();
            });
        });
    });
    describe('in keyboard mode', function () {
        beforeEach(function () {
            jest.spyOn(keyboardNavigation, 'getMode').mockReturnValue('keyboard');
        });
        describe('with all options', function () {
            beforeEach(function () {
                component = shallow(React.createElement(KeyboardNavigationObserver, { renderInKeyboardMode: renderInKeyboardMode, renderInMouseMode: renderInMouseMode, onEnterKeyboardMode: onEnterKeyboardModeCallback, onEnterMouseMode: onEnterMouseModeCallback }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('when mounted and mode is switched to mouse', function () {
            beforeEach(function () {
                jest.spyOn(keyboardNavigation, 'subscribe').mockImplementation(function (callback) { return callback('mouse'); });
                mounted = mount(React.createElement(KeyboardNavigationObserver, { renderInKeyboardMode: renderInKeyboardMode, renderInMouseMode: renderInMouseMode, onEnterKeyboardMode: onEnterKeyboardModeCallback, onEnterMouseMode: onEnterMouseModeCallback }));
            });
            afterEach(function () {
                if (mounted) {
                    mounted.unmount();
                }
            });
            it('triggers its onEnterMouseMode callback', function () {
                expect(onEnterMouseModeCallback).toHaveBeenCalled();
            });
            it('matches its snapshot', function () {
                expect(mounted).toMatchSnapshot();
            });
        });
    });
});
//# sourceMappingURL=KeyboardNavigationObserver.test.js.map