/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import { LayoutList, GutterSize } from '.';
describe('<LayoutList />', function () {
    var component;
    describe('as horizontal list', function () {
        describe('without props', function () {
            beforeEach(function () {
                component = shallow(React.createElement(LayoutList, { direction: "horizontal" }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with align "right"', function () {
            beforeEach(function () {
                component = shallow(React.createElement(LayoutList, { direction: "horizontal", align: "right" }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with gutterSize', function () {
            beforeEach(function () {
                component = shallow(React.createElement(LayoutList, { direction: "horizontal", gutterSize: GutterSize.LARGE }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with additional className', function () {
            beforeEach(function () {
                component = shallow(React.createElement(LayoutList, { direction: "horizontal", className: "TEST_CLASSNAME" }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with child content', function () {
            beforeEach(function () {
                component = shallow(React.createElement(LayoutList, { direction: "horizontal" }, "list content"));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('as vertical list', function () {
        describe('without props', function () {
            beforeEach(function () {
                component = shallow(React.createElement(LayoutList, { direction: "vertical" }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with gutterSize', function () {
            beforeEach(function () {
                component = shallow(React.createElement(LayoutList, { direction: "vertical", gutterSize: GutterSize.SMALL }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with additional className', function () {
            beforeEach(function () {
                component = shallow(React.createElement(LayoutList, { direction: "vertical", className: "TEST_CLASSNAME" }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with child content', function () {
            beforeEach(function () {
                component = shallow(React.createElement(LayoutList, { direction: "vertical" }, "list content"));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
});
//# sourceMappingURL=LayoutList.test.js.map