var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import '../../yamui';
import * as React from 'react';
import { FixedGridRow, FixedGridColumn, GutterSize } from '../FixedGrid';
import { MediaObjectSize } from './types';
import MediaObjectTitle from './MediaObjectTitle';
import MediaObjectMetadata from './MediaObjectMetadata';
import MediaObjectExtra from './MediaObjectExtra';
import './MediaObject.css';
export { MediaObjectSize };
var ImageWidthMap = (_a = {},
    _a[MediaObjectSize.XLARGE] = 72,
    _a[MediaObjectSize.LARGE] = 48,
    _a[MediaObjectSize.MEDIUM] = 40,
    _a[MediaObjectSize.SMALL] = 32,
    _a[MediaObjectSize.XSMALL] = 24,
    _a);
/**
 * A `MediaObject` renders an image on the left with blocks of descriptive content on the right. The
 * image area, and pieces of text content, are passed in as props, with size and layout determined
 * by the `size` prop.
 */
var MediaObject = /** @class */ (function (_super) {
    __extends(MediaObject, _super);
    function MediaObject() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MediaObject.prototype.render = function () {
        var _a = this.props, size = _a.size, imageContent = _a.imageContent, titleContent = _a.titleContent, metadataContent = _a.metadataContent, extraContent = _a.extraContent, children = _a.children, allowTextWrap = _a.allowTextWrap;
        var gutterSize = this.getGutterSize();
        var imageColumnClass = "y-media-object__size-" + size + "--image";
        var titleContentChild = titleContent && (React.createElement(MediaObjectTitle, { ellipsis: !allowTextWrap, size: size }, titleContent));
        var metadataContentChild = this.showMetadata() && (React.createElement(MediaObjectMetadata, { ellipsis: !allowTextWrap, size: size }, metadataContent));
        var extraContentChild = this.showExtra() && (React.createElement(MediaObjectExtra, { ellipsis: !allowTextWrap }, extraContent));
        return (React.createElement("div", { className: this.getClasses() },
            React.createElement(FixedGridRow, { gutterSize: gutterSize },
                React.createElement(FixedGridColumn, { width: ImageWidthMap[size], fixed: true, className: imageColumnClass }, imageContent),
                React.createElement(FixedGridColumn, null,
                    titleContentChild,
                    metadataContentChild,
                    extraContentChild,
                    children))));
    };
    MediaObject.prototype.getClasses = function () {
        var _a = this.props, className = _a.className, size = _a.size;
        var classes = ['y-media-object', "y-media-object__size-" + size];
        if (className) {
            classes.push(className);
        }
        return classes.join(' ');
    };
    MediaObject.prototype.getGutterSize = function () {
        var size = this.props.size;
        return size === MediaObjectSize.XLARGE ? GutterSize.XLARGE : GutterSize.MEDIUM;
    };
    MediaObject.prototype.showMetadata = function () {
        var _a = this.props, metadataContent = _a.metadataContent, size = _a.size;
        if (!metadataContent) {
            return false;
        }
        if (size === MediaObjectSize.XSMALL) {
            return false;
        }
        return true;
    };
    MediaObject.prototype.showExtra = function () {
        var _a = this.props, extraContent = _a.extraContent, size = _a.size;
        if (!extraContent) {
            return false;
        }
        return size === MediaObjectSize.XLARGE;
    };
    return MediaObject;
}(React.Component));
export default MediaObject;
var _a;
//# sourceMappingURL=MediaObject.js.map