/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import MediaObject, { MediaObjectSize } from '.';
describe('<MediaObject />', function () {
    var component;
    var image;
    var title;
    var metadata;
    var extra;
    var children;
    beforeEach(function () {
        image = React.createElement("img", { src: "404.jpg", alt: "", role: "presentation" });
        title = React.createElement("div", { className: "TITLE" }, "TITLE CONTENT");
        metadata = React.createElement("div", { className: "METADATA" }, "METADATA CONTENT");
        extra = React.createElement("div", { className: "EXTRA" }, "EXTRA CONTENT");
        children = React.createElement("div", { className: "CHILDREN" }, "CHILDREN CONTENT");
    });
    describe('with minimal options', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MediaObject, { size: MediaObjectSize.MEDIUM }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MediaObject, { size: MediaObjectSize.MEDIUM, className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with image content', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MediaObject, { size: MediaObjectSize.MEDIUM, imageContent: image }));
            component.render();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with title content', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MediaObject, { size: MediaObjectSize.MEDIUM, titleContent: title }));
            component.render();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('with allowTextWrap', function () {
            beforeEach(function () {
                component = shallow(React.createElement(MediaObject, { allowTextWrap: true, size: MediaObjectSize.MEDIUM, titleContent: title }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with metadata content', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MediaObject, { size: MediaObjectSize.MEDIUM, metadataContent: metadata }));
            component.render();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('at extra small size', function () {
            beforeEach(function () {
                component = shallow(React.createElement(MediaObject, { size: MediaObjectSize.XSMALL, metadataContent: metadata }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with allowTextWrap', function () {
            beforeEach(function () {
                component = shallow(React.createElement(MediaObject, { allowTextWrap: true, size: MediaObjectSize.MEDIUM, metadataContent: metadata }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with extra content', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MediaObject, { size: MediaObjectSize.MEDIUM, extraContent: extra }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('at extra large size', function () {
            beforeEach(function () {
                component = shallow(React.createElement(MediaObject, { size: MediaObjectSize.XLARGE, extraContent: extra }));
                component.render();
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with allowTextWrap', function () {
            beforeEach(function () {
                component = shallow(React.createElement(MediaObject, { allowTextWrap: true, size: MediaObjectSize.XLARGE, extraContent: extra }));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with arbitrary children', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MediaObject, { size: MediaObjectSize.MEDIUM }, children));
            component.render();
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=MediaObject.test.js.map