/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import MenuButton, { MenuItemType } from '.';
import { IconSize } from '../Icon';
import Reply from '../Icon/icons/Reply';
import Docx from '../Illustration/illustrations/Docx16';
describe('<MenuButton />', function () {
    var component;
    var ariaLabel = 'testAria';
    var menuItems;
    beforeEach(function () {
        menuItems = [
            {
                key: 'test1',
                text: 'test',
                type: MenuItemType.Normal,
                icon: Reply,
            },
            {
                key: 'test2',
                text: 'test',
                type: MenuItemType.Header,
                illustration: Docx,
            },
            {
                key: 'test3',
                text: 'test',
                href: 'http://bing.com',
                newWindow: true,
            },
            {
                key: 'test4',
                text: 'test',
                href: 'http://bing.com',
                newWindow: false,
            },
        ];
    });
    describe('with default options', function () {
        var testProps;
        beforeEach(function () {
            testProps = {
                item: {
                    key: 'test1',
                    name: 'test',
                },
                classNames: {
                    item: 'item',
                    divider: 'divider',
                    root: 'root',
                    linkContent: 'linkContent',
                    icon: 'icon',
                    checkmarkIcon: 'checkmarkIcon',
                    subMenuIcon: 'subMenuIcon',
                    label: 'label',
                    secondaryText: 'secondaryText',
                    splitContainer: 'splitContainer',
                    splitPrimary: 'splitPrimary',
                    splitMenu: 'splitMenu',
                    linkContentMenu: 'linkContentMenu',
                },
                index: 0,
                hasIcons: false,
            };
            component = shallow(React.createElement(MenuButton, { ariaLabel: ariaLabel, menuItems: menuItems }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        it('passes an icon method to fabric that defaults to the More icon with size large', function () {
            var onRenderIcon = component.find('CustomizedActionButton').prop('onRenderIcon');
            expect(onRenderIcon()).toMatchSnapshot();
        });
        it('passes a menu icon method to fabric that returns null to replace the chevron down icon', function () {
            var onRenderMenuIcon = component.find('CustomizedActionButton').prop('onRenderMenuIcon');
            expect(onRenderMenuIcon()).toMatchSnapshot();
        });
        it('passes contextualMenuItemAs method to fabric that returns a MenuButtonItem', function () {
            var menuProps = component.find('CustomizedActionButton').prop('menuProps');
            expect(menuProps.contextualMenuItemAs(testProps)).toMatchSnapshot();
        });
    });
    describe('with additional classnames', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MenuButton, { ariaLabel: ariaLabel, menuItems: menuItems, className: "TEST-ADDITIONAL-CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when an icon is passed', function () {
        describe('without iconSize', function () {
            beforeEach(function () {
                component = shallow(React.createElement(MenuButton, { ariaLabel: ariaLabel, menuItems: menuItems, icon: Reply }));
            });
            it('passes an icon method to fabric that returns an Icon with a default size of LARGE', function () {
                var onRenderIcon = component.find('CustomizedActionButton').prop('onRenderIcon');
                expect(onRenderIcon()).toMatchSnapshot();
            });
        });
        describe('with iconSize', function () {
            beforeEach(function () {
                component = shallow(React.createElement(MenuButton, { ariaLabel: ariaLabel, menuItems: menuItems, icon: Reply, iconSize: IconSize.XSMALL }));
            });
            it('passes an icon method to fabric that returns an Icon with the passed size', function () {
                var onRenderIcon = component.find('CustomizedActionButton').prop('onRenderIcon');
                expect(onRenderIcon()).toMatchSnapshot();
            });
        });
    });
    describe('with all props', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MenuButton, { ariaLabel: ariaLabel, menuItems: menuItems, className: "TEST-ADDITIONAL-CLASSNAME", icon: Reply, text: "TEST" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=MenuButton.test.js.map