/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import '../../yamui';
import * as React from 'react';
import { join } from '../../util/classNames';
import { IconSize } from '../Icon';
import Block, { TextColor } from '../Block';
import { TextSize } from '../Text';
import { FixedGridRow, FixedGridColumn, GutterSize } from '../FixedGrid';
import { ContextualMenuItemType } from 'office-ui-fabric-react/lib/ContextualMenu';
var getClasses = function (isHeader) {
    var classes = ['y-menu-button--item'];
    if (isHeader) {
        classes.push('y-menu-button--item-header');
    }
    return join(classes);
};
var getIconClasses = function (isDisabled) {
    var classes = ['y-menu-button--item-icon'];
    if (isDisabled) {
        classes.push('y-menu-button--item-icon__disabled');
    }
    return join(classes);
};
var getIconColumn = function (data, disabled) {
    var Icon = data && data.yamUIIcon;
    var Illustration = data && data.yamUIIllustration;
    if (Icon) {
        return (React.createElement(FixedGridColumn, { fixed: true, className: getIconClasses(disabled) },
            React.createElement(Icon, { size: IconSize.MEDIUM, block: true })));
    }
    else if (Illustration) {
        return (React.createElement(FixedGridColumn, { fixed: true, className: "y-menu-button--item-icon" },
            React.createElement(Illustration, { block: true })));
    }
    else {
        return null;
    }
};
var MenuButtonItem = function (props) {
    var _a = props.item, data = _a.data, name = _a.name, itemType = _a.itemType, _b = _a.disabled, disabled = _b === void 0 ? false : _b;
    var isHeader = itemType === ContextualMenuItemType.Header;
    var color = TextColor.SECONDARY;
    if (isHeader) {
        color = TextColor.PRIMARY;
    }
    else if (disabled) {
        color = TextColor.DISABLED;
    }
    var size = isHeader ? TextSize.SMALL : TextSize.MEDIUM_SUB;
    return (React.createElement(Block, { textColor: color, textSize: size, className: getClasses(isHeader) },
        React.createElement(FixedGridRow, { gutterSize: GutterSize.SMALL },
            getIconColumn(data, disabled),
            React.createElement(FixedGridColumn, { className: "y-menu-button--item-text" }, name))));
};
export default MenuButtonItem;
//# sourceMappingURL=MenuButtonItem.js.map