var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import { ContextualMenuItemType, } from 'office-ui-fabric-react/lib/ContextualMenu';
import MenuButtonItem from './MenuButtonItem';
import Reply from '../Icon/icons/Reply';
import Docx from '../Illustration/illustrations/Docx16';
describe('<MenuButtonItem />', function () {
    var props;
    var component;
    var baseItem;
    beforeEach(function () {
        baseItem = {
            key: 'test1',
            name: 'test',
        };
        props = {
            item: baseItem,
            classNames: {
                item: 'item',
                divider: 'divider',
                root: 'root',
                linkContent: 'linkContent',
                icon: 'icon',
                checkmarkIcon: 'checkmarkIcon',
                subMenuIcon: 'subMenuIcon',
                label: 'label',
                secondaryText: 'secondaryText',
                splitContainer: 'splitContainer',
                splitPrimary: 'splitPrimary',
                splitMenu: 'splitMenu',
                linkContentMenu: 'linkContentMenu',
            },
            index: 0,
            hasIcons: false,
        };
    });
    describe('with default options', function () {
        beforeEach(function () {
            component = shallow(React.createElement(MenuButtonItem, __assign({}, props)));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with an href', function () {
        beforeEach(function () {
            props = __assign({}, props, { item: __assign({}, props.item, { href: 'http://test.com' }) });
            component = shallow(React.createElement(MenuButtonItem, __assign({}, props)));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when it is disabled', function () {
        describe('without an icon', function () {
            beforeEach(function () {
                props = __assign({}, props, { item: __assign({}, props.item, { disabled: true }) });
                component = shallow(React.createElement(MenuButtonItem, __assign({}, props)));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with an icon', function () {
            beforeEach(function () {
                props = __assign({}, props, { item: __assign({}, props.item, { disabled: true, data: {
                            yamUIIcon: Reply,
                        } }) });
                component = shallow(React.createElement(MenuButtonItem, __assign({}, props)));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
        describe('with an illustration', function () {
            beforeEach(function () {
                props = __assign({}, props, { item: __assign({}, props.item, { disabled: true, data: {
                            yamUIIllustration: Docx,
                        } }) });
                component = shallow(React.createElement(MenuButtonItem, __assign({}, props)));
            });
            it('matches its snapshot', function () {
                expect(component).toMatchSnapshot();
            });
        });
    });
    describe('with an icon passed', function () {
        beforeEach(function () {
            props = __assign({}, props, { item: __assign({}, props.item, { data: {
                        yamUIIcon: Reply,
                    } }) });
            component = shallow(React.createElement(MenuButtonItem, __assign({}, props)));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when it is a header type', function () {
        beforeEach(function () {
            props = __assign({}, props, { item: __assign({}, props.item, { itemType: ContextualMenuItemType.Header }) });
            component = shallow(React.createElement(MenuButtonItem, __assign({}, props)));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=MenuButtonItem.test.js.map