/// <reference types="react" />
import '../../yamui';
import * as React from 'react';
import { NestableBaseComponentProps, FocusableComponentProps } from '../../util/BaseComponent/props';
import './NavigationLink.css';
export interface NavigationLinkProps extends NestableBaseComponentProps, FocusableComponentProps {
    /**
     * Whether the clickable should be `display: block`.
     */
    block?: boolean;
    /**
     * URL or a URL fragment that the link points to.
     */
    href: string;
    /**
     * Whether the link should open in a new window. It securely removes access to the opening window.
     */
    newWindow?: boolean;
    /**
     * If present, indicates the link refers to the current page. This is usually used in cases where the link
     * is visually styled to indicate it is selected or is the current page, such as in a navigation list.
     */
    ariaCurrent?: 'page';
    /**
     * Title or description of the linked document for screenreaders.
     */
    ariaLabel?: string;
    /**
     * Title or description of the linked document for the anchor tag. You should generally avoid using this.
     */
    title?: string;
    /**
     * Whether to remove all styles from the link. Useful for allowing a large area to be clickable
     * while nesting `FakeLink` components to show link and hover state visuals.
     */
    unstyled?: boolean;
}
/**
 * A `NavigationLink` renders an `a` tag for navigation between web pages.
 */
export default class NavigationLink extends React.Component<NavigationLinkProps> {
    private anchorRef;
    constructor(props: NavigationLinkProps);
    render(): JSX.Element;
    focus(): void;
    private getClasses();
}
