var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import '../../yamui';
import * as React from 'react';
import { join } from '../../util/classNames';
import Block, { GutterSize, TextColor, TextSize } from '../Block';
import Box from '../Box';
import Clickable from '../Clickable';
import EditableText from '../EditableText';
import RemoveIcon from '../Icon/icons/Cancel';
import { IconSize } from '../Icon';
import Image from '../Image';
import MediaObject, { MediaObjectSize } from '../MediaObject';
import ProgressIndicator from '../ProgressIndicator';
import Spinner, { SpinnerColor, SpinnerSize } from '../Spinner';
import './PreviewCard.css';
/**
 * PreviewCard is a compact representation of an uploaded file or other attachment. It supports an
 * editable description, and a loading experience (Spinner or percentage ProgressIndicator).
 */
var PreviewCard = /** @class */ (function (_super) {
    __extends(PreviewCard, _super);
    function PreviewCard(props) {
        var _this = _super.call(this, props) || this;
        _this.handleRemoveClick = function (event) {
            event.stopPropagation();
            _this.props.onRemoveClick();
        };
        _this.enterEditMode = function () {
            _this.setState(function () { return ({ isEditing: true }); });
        };
        _this.exitEditMode = function () {
            _this.setState(function () { return ({ isEditing: false }); });
        };
        _this.state = {
            isEditing: false,
        };
        return _this;
    }
    PreviewCard.prototype.render = function () {
        var mediaObjectProps = {
            size: MediaObjectSize.MEDIUM,
            className: 'y-previewCard--media',
            imageContent: this.getImageContent(),
            titleContent: this.getNameContent(),
            metadataContent: this.getDescriptionContent(),
        };
        var onClick = this.allowOnClick() ? this.props.onClick : undefined;
        return (React.createElement(Box, { className: this.getClassnames(), onClick: onClick },
            React.createElement(MediaObject, __assign({}, mediaObjectProps)),
            this.getRemoveButton(),
            this.getProgressIndicator()));
    };
    PreviewCard.prototype.getClassnames = function () {
        var classes = ['y-previewCard', this.props.className];
        if (this.allowOnClick()) {
            classes.push('y-previewCard__hasClick');
        }
        return join(classes);
    };
    // Allow onClick callback and hover styling if onClick prop was provided and we're not in edit mode
    PreviewCard.prototype.allowOnClick = function () {
        return !!this.props.onClick && !this.state.isEditing;
    };
    PreviewCard.prototype.getNameContent = function () {
        var _a = this.props, name = _a.name, onClick = _a.onClick, clickAriaLabel = _a.clickAriaLabel;
        var size = this.state.isEditing ? TextSize.XSMALL : undefined;
        // Note that the actual onClick handler is on the outer Box wrapper,
        // while the clickAriaLabel is here on the keyboard-tabbable element.
        var content = onClick ? (React.createElement(Clickable, { ariaLabel: clickAriaLabel, unstyled: true }, name)) : (name);
        return React.createElement(Block, { textSize: size }, content);
    };
    PreviewCard.prototype.getRemoveButton = function () {
        var _a = this.props, onRemoveClick = _a.onRemoveClick, removeAriaLabel = _a.removeAriaLabel;
        if (onRemoveClick) {
            return (React.createElement("span", { className: "y-previewCard--remove" },
                React.createElement(Clickable, { onClick: this.handleRemoveClick, unstyled: true, ariaLabel: removeAriaLabel, block: true },
                    React.createElement(Block, { padding: GutterSize.SMALL },
                        React.createElement(RemoveIcon, { size: IconSize.XSMALL, block: true })))));
        }
        return null;
    };
    PreviewCard.prototype.getProgressIndicator = function () {
        if (this.shouldShowProgressIndicator()) {
            var _a = this.props, loadingText = _a.loadingText, progress = _a.progress;
            return (React.createElement(ProgressIndicator, { className: "y-previewCard--progress", ariaValueText: loadingText, percentComplete: progress }));
        }
        return null;
    };
    PreviewCard.prototype.getImageContent = function () {
        var _a = this.props, imageUrl = _a.imageUrl, _b = _a.imageDescription, imageDescription = _b === void 0 ? '' : _b;
        if (imageUrl) {
            return React.createElement(Image, { source: imageUrl, fullWidth: true, description: imageDescription });
        }
        return null;
    };
    PreviewCard.prototype.getDescriptionContent = function () {
        var _a = this.props, description = _a.description, isDescriptionEditable = _a.isDescriptionEditable;
        if (this.shouldShowLoadingSpinner()) {
            return this.getLoadingSpinner();
        }
        if (isDescriptionEditable) {
            return this.getEditableText();
        }
        return description;
    };
    PreviewCard.prototype.getEditableText = function () {
        var _a = this.props, description = _a.description, descriptionMaxLength = _a.descriptionMaxLength, emptyEditableDescriptionText = _a.emptyEditableDescriptionText, onDescriptionChange = _a.onDescriptionChange;
        var blockPush = this.state.isEditing ? -3 : 0;
        return (React.createElement(Block, { push: blockPush, textColor: TextColor.METADATA },
            React.createElement(EditableText, { text: description, promptText: emptyEditableDescriptionText, placeHolder: emptyEditableDescriptionText, maxLength: descriptionMaxLength, onUpdate: onDescriptionChange, onBeginEditing: this.enterEditMode, onEndEditing: this.exitEditMode })));
    };
    PreviewCard.prototype.getLoadingSpinner = function () {
        var loadingText = this.props.loadingText;
        return (React.createElement(Block, { textColor: TextColor.METADATA, className: "y-previewCard--spinner", push: 1 },
            React.createElement(Spinner, { text: loadingText, size: SpinnerSize.XSMALL, color: SpinnerColor.METADATA })));
    };
    PreviewCard.prototype.hasProgress = function () {
        return typeof this.props.progress === 'number';
    };
    PreviewCard.prototype.shouldShowLoadingSpinner = function () {
        return this.props.isLoading && !this.hasProgress();
    };
    PreviewCard.prototype.shouldShowProgressIndicator = function () {
        return this.props.isLoading && this.hasProgress();
    };
    return PreviewCard;
}(React.Component));
export default PreviewCard;
//# sourceMappingURL=PreviewCard.js.map