/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import Clickable from '../Clickable';
import EditableText from '../EditableText';
import PreviewCard from './index';
import { renderIntoDocument, findRenderedComponentWithType } from 'react-dom/test-utils';
describe('<PreviewCard />', function () {
    var component;
    var onClick;
    var onChange;
    describe('with minimal options', function () {
        beforeEach(function () {
            component = shallow(React.createElement(PreviewCard, { name: "Filename.gif" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with description', function () {
        beforeEach(function () {
            component = shallow(React.createElement(PreviewCard, { name: "Filename.gif", description: "file description" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when description is edible', function () {
        describe('with onDescriptionChange callback', function () {
            var jsxComponent;
            var testComponent;
            beforeEach(function () {
                onChange = jest.fn();
                jsxComponent = (React.createElement(PreviewCard, { name: "Filename.gif", description: "file description", isDescriptionEditable: true, descriptionMaxLength: 120, emptyEditableDescriptionText: "empty placeholder text", onDescriptionChange: onChange }));
            });
            it('matches its snapshot', function () {
                expect(shallow(jsxComponent)).toMatchSnapshot();
            });
            describe('when entering edit mode', function () {
                beforeEach(function () {
                    var renderedPreviewCard = renderIntoDocument(jsxComponent);
                    var renderedEditableText = findRenderedComponentWithType(renderedPreviewCard, EditableText);
                    renderedEditableText.props.onBeginEditing();
                    testComponent = findRenderedComponentWithType(renderedPreviewCard, PreviewCard).render();
                });
                it('matches its snapshot', function () {
                    expect(testComponent).toMatchSnapshot();
                });
            });
            describe('when exiting edit mode', function () {
                beforeEach(function () {
                    var renderedPreviewCard = renderIntoDocument(jsxComponent);
                    var renderedEditableText = findRenderedComponentWithType(renderedPreviewCard, EditableText);
                    renderedEditableText.props.onEndEditing();
                    testComponent = findRenderedComponentWithType(renderedPreviewCard, PreviewCard).render();
                });
                it('matches its snapshot', function () {
                    expect(testComponent).toMatchSnapshot();
                });
            });
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = shallow(React.createElement(PreviewCard, { name: "Filename.gif", className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with image', function () {
        beforeEach(function () {
            component = shallow(React.createElement(PreviewCard, { name: "Filename.gif", imageUrl: "filename.png", imageDescription: "file description" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when loading', function () {
        beforeEach(function () {
            component = shallow(React.createElement(PreviewCard, { name: "Filename.gif", isLoading: true, loadingText: "loading..." }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with loading progress', function () {
        beforeEach(function () {
            component = shallow(React.createElement(PreviewCard, { name: "Filename.gif", isLoading: true, loadingText: "Uploading, currently at 50%", progress: 0.5 }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with onClick handler', function () {
        beforeEach(function () {
            onClick = jest.fn();
            component = shallow(React.createElement(PreviewCard, { name: "Filename.gif", onClick: onClick, clickAriaLabel: "Show file preview" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('when clicked', function () {
            beforeEach(function () {
                component.simulate('click');
            });
            it('triggers the onClick callback prop', function () {
                expect(onClick).toHaveBeenCalledTimes(1);
            });
        });
    });
    describe('with onRemoveClick handler', function () {
        beforeEach(function () {
            onClick = jest.fn();
            component = shallow(React.createElement(PreviewCard, { name: "Filename.gif", onRemoveClick: onClick, removeAriaLabel: "Remove this attachment" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('when the remove button is clicked', function () {
            beforeEach(function () {
                var onRemoveClick = component.find(Clickable).prop('onClick');
                onRemoveClick({ stopPropagation: function () { return undefined; } });
            });
            it('triggers the onRemoveClick callback prop', function () {
                expect(onClick).toHaveBeenCalledTimes(1);
            });
        });
    });
});
//# sourceMappingURL=PreviewCard.test.js.map