/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import Spinner, { SpinnerColor, SpinnerSize } from '.';
describe('<Spinner />', function () {
    var component;
    describe('with additional className', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Spinner, { className: "TEST_CLASSNAME", text: "Loading" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with visible text', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Spinner, { text: "Loading" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with invisible text', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Spinner, { text: "Loading", hideText: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with dark color', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Spinner, { text: "Loading", color: SpinnerColor.DARK }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with metadata color', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Spinner, { text: "Loading", color: SpinnerColor.METADATA }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with a size', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Spinner, { text: "Loading", size: SpinnerSize.XSMALL }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('when centered', function () {
        beforeEach(function () {
            component = shallow(React.createElement(Spinner, { text: "Loading", isCentered: true }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=Spinner.test.js.map