var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import '../../yamui';
import * as React from 'react';
import SuggestionsListItem from './SuggestionsListItem';
import Spinner from '../Spinner';
import Text, { TextSize, TextColor } from '../Text';
import Block, { GutterSize } from '../Block';
import './SuggestionsList.css';
var hasResults = function (props) {
    return !!props.groupedItems && props.groupedItems.length > 0;
};
var withResultsClass = 'y-suggestions-list--with-results';
var withStatusClass = 'y-suggestions-list--with-status';
/**
 * A `SuggestionsList` displays a list of search results in a dropdown.
 */
var SuggestionsList = /** @class */ (function (_super) {
    __extends(SuggestionsList, _super);
    function SuggestionsList() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.getGroupResults = function (group) {
            var items = group.items.map(_this.getResultItem);
            return (React.createElement("li", { key: group.title },
                React.createElement("ul", null, items)));
        };
        _this.getResultItem = function (item) {
            var _a = _this.props, searchText = _a.searchText, selectedId = _a.selectedId, onItemSelected = _a.onItemSelected;
            var isSelected = item.id === selectedId;
            return (React.createElement("li", { key: item.id },
                React.createElement(SuggestionsListItem, __assign({ searchText: searchText, isSelected: isSelected, onSelect: onItemSelected }, item))));
        };
        return _this;
    }
    SuggestionsList.prototype.render = function () {
        var status = this.getSearchStatus();
        var results = this.getGroupedResults();
        var classNames = ['y-suggestions-list', 'y-hc-border'];
        if (status) {
            classNames.push(withStatusClass);
        }
        if (results) {
            classNames.push(withResultsClass);
        }
        return (React.createElement("div", { className: classNames.join(' ') },
            results,
            status));
    };
    SuggestionsList.prototype.getGroupedResults = function () {
        if (!hasResults(this.props)) {
            return null;
        }
        return React.createElement("ul", { className: "y-suggestions-list--results" }, this.props.groupedItems.map(this.getGroupResults));
    };
    SuggestionsList.prototype.getSearchStatus = function () {
        return this.props.isLoading ? this.getLoading() : this.getNoResults();
    };
    SuggestionsList.prototype.getLoading = function () {
        return (React.createElement(Block, { push: -2 },
            React.createElement(Spinner, { text: this.props.loadingText, className: "y-suggestions-list--loading", isCentered: true })));
    };
    SuggestionsList.prototype.getNoResults = function () {
        if (hasResults(this.props)) {
            return null;
        }
        return (React.createElement(Block, { textAlign: "center", padding: GutterSize.LARGE, textSize: TextSize.SMALL },
            React.createElement(Text, { color: TextColor.METADATA, className: "y-suggestions-list--no-results" }, this.props.noResultsText)));
    };
    return SuggestionsList;
}(React.PureComponent));
export default SuggestionsList;
//# sourceMappingURL=SuggestionsList.js.map