var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { shallow } from 'enzyme';
import SuggestionsListItem from './SuggestionsListItem';
import { BorderType } from '../Avatar';
describe('<SuggestionsListItem />', function () {
    var rendered;
    var onSelect;
    var getProps = function (overrides) {
        onSelect = jest.fn();
        return __assign({ onSelect: onSelect, isSelected: false, id: '1', imageUrl: 'imageUrl', name: 'John Smith', description: 'Software Engineer', searchText: 'Joh' }, overrides);
    };
    beforeEach(function () {
        onSelect = jest.fn();
    });
    describe('when isSelected=true', function () {
        beforeEach(function () {
            rendered = shallow(React.createElement(SuggestionsListItem, __assign({}, getProps({ isSelected: true }))));
        });
        it('renders as expected', function () {
            expect(rendered).toMatchSnapshot();
        });
    });
    describe('when isSelected=false', function () {
        beforeEach(function () {
            rendered = shallow(React.createElement(SuggestionsListItem, __assign({}, getProps({ isSelected: false }))));
        });
        it('renders as expected', function () {
            expect(rendered).toMatchSnapshot();
        });
    });
    describe('when searchText has a "("', function () {
        beforeEach(function () {
            rendered = shallow(React.createElement(SuggestionsListItem, __assign({}, getProps({ name: 'Jo(hn)', searchText: 'Jo(' }))));
        });
        it('renders as expected', function () {
            expect(rendered).toMatchSnapshot();
        });
    });
    describe('with avatarProps', function () {
        beforeEach(function () {
            var avatarProps = { borderType: BorderType.SOFT };
            rendered = shallow(React.createElement(SuggestionsListItem, __assign({}, getProps({ avatarProps: avatarProps }))));
        });
        it('renders as expected', function () {
            expect(rendered).toMatchSnapshot();
        });
    });
    describe('when selecting', function () {
        var preventDefault;
        beforeEach(function () {
            rendered = shallow(React.createElement(SuggestionsListItem, __assign({}, getProps())));
            preventDefault = jest.fn();
            rendered.simulate('mouseDown', { preventDefault: preventDefault });
        });
        it('calls props.onSelect', function () {
            expect(onSelect).toBeCalled();
        });
        it('calls event preventDefault', function () {
            expect(preventDefault).toBeCalled();
        });
    });
});
//# sourceMappingURL=SuggestionsListItem.test.js.map