/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { renderIntoDocument, findRenderedDOMComponentWithClass } from 'react-dom/test-utils';
import Text, { TextColor, TextSize } from '.';
var render = function (jsx) {
    var renderedText = renderIntoDocument(jsx);
    return findRenderedDOMComponentWithClass(renderedText, 'y-text');
};
describe('<Text />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, null, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, { className: "TEST_CLASSNAME" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with a valid size', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, { size: TextSize.XLARGE }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with a valid size and maxWidth', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, { size: TextSize.XLARGE, maxWidth: "200px" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with bold', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, { bold: true }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with uppercase', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, { uppercase: true }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with maxWidth 500px', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, { maxWidth: "500px" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with color secondary', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, { color: TextColor.SECONDARY }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with screenreader text', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, { screenreaderText: "SCREENREADER TEXT" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with screenreader text empty string', function () {
        beforeEach(function () {
            component = render(React.createElement(Text, { screenreaderText: "" }, "test content"));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
});
//# sourceMappingURL=Text.test.js.map