/// <reference types="react" />
import * as React from 'react';
export interface DebouncedOnChangeProps {
    /**
     * Callback for the onChange event.
     */
    onChange?: ((newValue: any) => void);
    /**
     * Debounced callback for the onChange event.
     */
    debouncedOnChange?: ((newValue: any) => void);
    /**
     * Component will trigger `onChange` after users stop typing for `debouncedOnChangeTime`
     * milliseconds.
     * @default 700
     */
    debouncedOnChangeTime?: number;
}
export interface DebouncedOnChangePrivateProps {
    /**
     * Used to pass both onChange and debouncedOnChange to the contained component.
     */
    unifiedOnChange?: ((newValue: any) => void);
}
export interface NestedComponentProps<T extends DebouncedOnChangePrivateProps> {
    component: React.ComponentClass<T> | React.StatelessComponent<T>;
}
export declare type DebouncedOnChangeComponentProps<T> = DebouncedOnChangeProps & NestedComponentProps<T>;
export default class DebouncedOnChangeComponent<T extends DebouncedOnChangePrivateProps> extends React.Component<DebouncedOnChangeComponentProps<T>> {
    static defaultProps: {
        debouncedOnChangeTime: number;
    };
    private async;
    private debouncedOnChange;
    constructor(props: DebouncedOnChangeComponentProps<T>);
    render(): JSX.Element;
    componentWillUnmount(): void;
    private handleChange;
}
