var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
import * as React from 'react';
import { mount } from 'enzyme';
import DebouncedOnChange from '.';
import { Async } from 'office-ui-fabric-react/lib/Utilities';
var InnerComponent = function (props) { return React.createElement("input", __assign({}, props)); };
var TestComponent = function (props) { return (React.createElement(InnerComponent, { onChange: props.unifiedOnChange })); };
var DebouncedOnChangeTestComponent = function (props) {
    return React.createElement(DebouncedOnChange, __assign({}, props, { component: TestComponent }));
};
describe('<BaseTextField />', function () {
    var component;
    describe('with default options', function () {
        beforeEach(function () {
            component = mount(React.createElement(DebouncedOnChangeTestComponent, null));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with onChange handler', function () {
        var callback;
        beforeEach(function () {
            callback = jest.fn();
            component = mount(React.createElement(DebouncedOnChangeTestComponent, { onChange: callback }));
        });
        describe('when a change in made', function () {
            beforeEach(function () {
                var innerComponentWrapper = component.find('input');
                innerComponentWrapper.prop('onChange')('new value');
            });
            it('triggers the onChange callback', function () {
                expect(callback).toHaveBeenCalledWith('new value');
            });
        });
        describe('unmount', function () {
            var disposeSpy;
            beforeEach(function () {
                disposeSpy = jest.spyOn(Async.prototype, 'dispose');
                component.unmount();
            });
            it('disposes its async instance', function () {
                expect(disposeSpy).not.toHaveBeenCalled();
            });
        });
    });
    describe('with debouncedOnChange handler', function () {
        var callback;
        beforeEach(function () {
            callback = jest.fn();
            component = mount(React.createElement(DebouncedOnChangeTestComponent, { debouncedOnChange: callback, debouncedOnChangeTime: 0 }));
        });
        describe('when a change is made', function () {
            beforeEach(function () {
                var innerComponentWrapper = component.find('input');
                innerComponentWrapper.prop('onChange')('new value');
            });
            it('triggers the debouncedOnChange callback', function () {
                expect(callback).toHaveBeenCalledWith('new value');
            });
        });
        describe('unmount', function () {
            var disposeSpy;
            beforeEach(function () {
                disposeSpy = jest.spyOn(Async.prototype, 'dispose');
                component.unmount();
            });
            it('calls async dispose', function () {
                expect(disposeSpy).toHaveBeenCalled();
            });
        });
    });
});
//# sourceMappingURL=index.test.js.map