/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
jest.mock('./KeyboardNavigationEventListener');
import KeyboardNavigationEventListener from './KeyboardNavigationEventListener';
import { getMode, subscribe, unsubscribe } from './keyboardNavigation';
describe('keyboardNavigation', function () {
    var callback;
    beforeEach(function () {
        callback = jest.fn();
    });
    afterEach(function () {
        jest.resetAllMocks();
    });
    describe('getMode()', function () {
        beforeEach(function () {
            jest.spyOn(KeyboardNavigationEventListener.prototype, 'getMode').mockReturnValue('fake mode');
        });
        it('calls getMode on KeyboardNavigationEventListener', function () {
            expect(getMode()).toBe('fake mode');
        });
    });
    describe('subscribe()', function () {
        beforeEach(function () {
            jest.spyOn(KeyboardNavigationEventListener.prototype, 'subscribe').mockImplementation(function (cb) { return cb('new fake mode'); });
            subscribe(callback);
        });
        it('is passed to KeyboardNavigationEventListener', function () {
            expect(callback).toHaveBeenCalledWith('new fake mode');
        });
    });
    describe('unsubscribe()', function () {
        beforeEach(function () {
            jest
                .spyOn(KeyboardNavigationEventListener.prototype, 'unsubscribe')
                .mockImplementation(function (cb) { return cb('another fake mode'); });
            unsubscribe(callback);
        });
        it('is passed to KeyboardNavigationEventListener', function () {
            expect(callback).toHaveBeenCalledWith('another fake mode');
        });
    });
});
//# sourceMappingURL=keyboardNavigation.test.js.map